@@ -27,7 +27,6 @@
 #include "native_check_cpu_base.cc"
 
 using namespace com::centreon::agent;
-using namespace com::centreon;
 using namespace com::centreon::agent::check_cpu_detail;
 
 /**************************************************************************
@@ -270,29 +269,29 @@ pdh_cpu_time_snapshot::pdh_cpu_time_snapshot(unsigned nb_core,
 ***************************************************************************/
 using windows_cpu_to_status = cpu_to_status<e_proc_stat_index::nb_field>;
 
-using cpu_to_status_constructor = std::function<windows_cpu_to_status(
-    const common::threshold& /*threshold*/)>;
+using cpu_to_status_constructor =
+    std::function<windows_cpu_to_status(double /*threshold*/)>;
 
 #define BY_TYPE_CPU_TO_STATUS(TYPE_METRIC)                                     \
   {"warning-core-" #TYPE_METRIC,                                               \
-   [](const common::threshold& threshold) {                                    \
+   [](double threshold) {                                                      \
      return windows_cpu_to_status(                                             \
          e_status::warning, e_proc_stat_index::TYPE_METRIC, false, threshold); \
    }},                                                                         \
       {"critical-core-" #TYPE_METRIC,                                          \
-       [](const common::threshold& threshold) {                                \
+       [](double threshold) {                                                  \
          return windows_cpu_to_status(e_status::critical,                      \
                                       e_proc_stat_index::TYPE_METRIC, false,   \
                                       threshold);                              \
        }},                                                                     \
       {"warning-average-" #TYPE_METRIC,                                        \
-       [](const common::threshold& threshold) {                                \
+       [](double threshold) {                                                  \
          return windows_cpu_to_status(e_status::warning,                       \
                                       e_proc_stat_index::TYPE_METRIC, true,    \
                                       threshold);                              \
        }},                                                                     \
   {                                                                            \
-    "critical-average-" #TYPE_METRIC, [](const common::threshold& threshold) { \
+    "critical-average-" #TYPE_METRIC, [](double threshold) {                   \
       return windows_cpu_to_status(e_status::critical,                         \
                                    e_proc_stat_index::TYPE_METRIC, true,       \
                                    threshold);                                 \
@@ -307,24 +306,24 @@ using cpu_to_status_constructor = std::function<windows_cpu_to_status(
 static const absl::flat_hash_map<std::string_view, cpu_to_status_constructor>
     _label_to_cpu_to_status = {
         {"warning-core",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return windows_cpu_to_status(e_status::warning,
                                         e_proc_stat_index::nb_field, false,
                                         threshold);
          }},
         {"critical-core",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return windows_cpu_to_status(e_status::critical,
                                         e_proc_stat_index::nb_field, false,
                                         threshold);
          }},
         {"warning-average",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return windows_cpu_to_status(
                e_status::warning, e_proc_stat_index::nb_field, true, threshold);
          }},
         {"critical-average",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return windows_cpu_to_status(e_status::critical,
                                         e_proc_stat_index::nb_field, true,
                                         threshold);
@@ -338,11 +337,7 @@ static const absl::flat_hash_map<std::string_view, cpu_to_status_constructor>
  * @param io_context
  * @param logger
  * @param first_start_expected start expected
- * @param check_interval check interval between two checks (not only this but
- * also others)
  * @param serv service
- * @param cmd_name
- * @param cmd_line
  * @param args native plugin arguments
  * @param cnf engine configuration received object
  * @param handler called at measure completion
@@ -350,10 +345,7 @@ static const absl::flat_hash_map<std::string_view, cpu_to_status_constructor>
 check_cpu::check_cpu(const std::shared_ptr<asio::io_context>& io_context,
                      const std::shared_ptr<spdlog::logger>& logger,
                      time_point first_start_expected,
-                     duration check_interval,
-                     const std::string& serv,
-                     const std::string& cmd_name,
-                     const std::string& cmd_line,
+                     const Service& serv,
                      const rapidjson::Value& args,
                      const engine_to_agent_request_ptr& cnf,
                      check::completion_handler&& handler,
@@ -362,10 +354,7 @@ check_cpu::check_cpu(const std::shared_ptr<asio::io_context>& io_context,
           io_context,
           logger,
           first_start_expected,
-          check_interval,
           serv,
-          cmd_name,
-          cmd_line,
           args,
           cnf,
           std::move(handler),
@@ -379,22 +368,12 @@ check_cpu::check_cpu(const std::shared_ptr<asio::io_context>& io_context,
         auto cpu_to_status_search = _label_to_cpu_to_status.find(
             absl::AsciiStrToLower(member_iter->name.GetString()));
         if (cpu_to_status_search != _label_to_cpu_to_status.end()) {
-          std::optional<std::string> val = check::get_string(
+          std::optional<double> threshold = check::get_double(
               get_command_name(), member_iter->name.GetString(),
-              member_iter->value);
-          if (val) {
-            common::threshold thres(val.value());
-            if (!thres.is_valid()) {
-              SPDLOG_LOGGER_ERROR(logger, "command: {}, invalid threshold: {}",
-                                  get_command_name(), val.value());
-              throw exceptions::msg_fmt("command: {}, invalid threshold: {}",
-                                        get_command_name(), val.value());
-            }
-            thres.set_default_low(0);
-            thres.unit_multiplier(1.0 / 100.0);
+              member_iter->value, true);
+          if (threshold) {
             check_cpu_detail::cpu_to_status cpu_checker =
-                cpu_to_status_search->second(thres);
-
+                cpu_to_status_search->second(*threshold / 100);
             _cpu_to_status.emplace(
                 std::make_tuple(cpu_checker.get_proc_stat_index(),
                                 cpu_checker.is_average(),
@@ -402,14 +381,15 @@ check_cpu::check_cpu(const std::shared_ptr<asio::io_context>& io_context,
                 cpu_checker);
           }
         } else if (member_iter->name == "use-nt-query-system-information") {
-          std::optional<bool> val = get_bool(
-              cmd_name, "use-nt-query-system-information", member_iter->value);
+          std::optional<bool> val =
+              get_bool(get_command_name(), "use-nt-query-system-information",
+                       member_iter->value);
           if (val) {
             _use_nt_query_system_information = *val;
           }
         } else if (member_iter->name != "cpu-detailed") {
           SPDLOG_LOGGER_ERROR(logger, "command: {}, unknown parameter: {}",
-                              cmd_name, member_iter->name);
+                              get_command_name(), member_iter->name);
         }
       }
     }
@@ -471,12 +451,6 @@ e_status check_cpu::compute(
 
 void check_cpu::help(std::ostream& help_stream) {
   help_stream << R"(
-- Threshold expression syntax follows standard monitoring rules:
-  x     : alert if value > x
-  x:    : alert if value < x
-  x:y   : alert if value < x or value > y
-  @x:y  : alert if value >= x and value <= y
-
 - cpu params:
     use-nt-query-system-information (default true): true: use NtQuerySystemInformation instead of performance counters
     cpu-detailed (default false): true: add detailed cpu usage metrics
@@ -497,10 +471,10 @@ void check_cpu::help(std::ostream& help_stream) {
     "check": "cpu_percentage",
     "args": {
         "cpu-detailed": true,
-        "warning-core": "80",
-        "critical-core": "90",
-        "warning-average": "60",
-        "critical-average": "70"
+        "warning-core": 80,
+        "critical-core": 90,
+        "warning-average": 60,
+        "critical-average": 70
     }
   }
   Examples of output:
