@@ -195,8 +195,7 @@ void w_memory_info::dump_to_output(std::string* output) const {
 using windows_mem_to_status = measure_to_status<e_memory_metric::nb_metric>;
 
 using mem_to_status_constructor =
-    std::function<std::unique_ptr<windows_mem_to_status>(
-        const common::threshold& /*threshold*/)>;
+    std::function<std::unique_ptr<windows_mem_to_status>(double /*threshold*/)>;
 
 /**
  * @brief status threshold defines
@@ -206,150 +205,150 @@ static const absl::flat_hash_map<std::string_view, mem_to_status_constructor>
     _label_to_mem_to_status = {
         // phys
         {"critical-usage",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
                e_status::critical, e_memory_metric::phys_used, threshold,
-               e_memory_metric::phys_total, false);
+               e_memory_metric::phys_total, false, false);
          }},
         {"warning-usage",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
                e_status::warning, e_memory_metric::phys_used, threshold,
-               e_memory_metric::phys_total, false);
+               e_memory_metric::phys_total, false, false);
          }},
         {"critical-usage-free",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
                e_status::critical, e_memory_metric::phys_free, threshold,
-               e_memory_metric::phys_total, false);
+               e_memory_metric::phys_total, false, true);
          }},
         {"warning-usage-free",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
                e_status::warning, e_memory_metric::phys_free, threshold,
-               e_memory_metric::phys_total, false);
+               e_memory_metric::phys_total, false, true);
          }},
         {"critical-usage-prct",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
-               e_status::critical, e_memory_metric::phys_used, threshold,
-               e_memory_metric::phys_total, true);
+               e_status::critical, e_memory_metric::phys_used, threshold / 100,
+               e_memory_metric::phys_total, true, false);
          }},
         {"warning-usage-prct",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
-               e_status::warning, e_memory_metric::phys_used, threshold,
-               e_memory_metric::phys_total, true);
+               e_status::warning, e_memory_metric::phys_used, threshold / 100,
+               e_memory_metric::phys_total, true, false);
          }},
         {"critical-usage-free-prct",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
-               e_status::critical, e_memory_metric::phys_free, threshold,
-               e_memory_metric::phys_total, true);
+               e_status::critical, e_memory_metric::phys_free, threshold / 100,
+               e_memory_metric::phys_total, true, true);
          }},
         {"warning-usage-free-prct",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
-               e_status::warning, e_memory_metric::phys_free, threshold,
-               e_memory_metric::phys_total, true);
+               e_status::warning, e_memory_metric::phys_free, threshold / 100,
+               e_memory_metric::phys_total, true, true);
          }},
         // swap
         {"critical-swap",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
                e_status::critical, e_memory_metric::swap_used, threshold,
-               e_memory_metric::swap_total, false);
+               e_memory_metric::swap_total, false, false);
          }},
         {"warning-swap",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
                e_status::warning, e_memory_metric::swap_used, threshold,
-               e_memory_metric::swap_total, false);
+               e_memory_metric::swap_total, false, false);
          }},
         {"critical-swap-free",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
                e_status::critical, e_memory_metric::swap_free, threshold,
-               e_memory_metric::swap_total, false);
+               e_memory_metric::swap_total, false, true);
          }},
         {"warning-swap-free",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
                e_status::warning, e_memory_metric::swap_free, threshold,
-               e_memory_metric::swap_total, false);
+               e_memory_metric::swap_total, false, true);
          }},
         {"critical-swap-prct",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
-               e_status::critical, e_memory_metric::swap_used, threshold,
-               e_memory_metric::swap_total, true);
+               e_status::critical, e_memory_metric::swap_used, threshold / 100,
+               e_memory_metric::swap_total, true, false);
          }},
         {"warning-swap-prct",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
-               e_status::warning, e_memory_metric::swap_used, threshold,
-               e_memory_metric::swap_total, true);
+               e_status::warning, e_memory_metric::swap_used, threshold / 100,
+               e_memory_metric::swap_total, true, false);
          }},
         {"critical-swap-free-prct",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
-               e_status::critical, e_memory_metric::swap_free, threshold,
-               e_memory_metric::swap_total, true);
+               e_status::critical, e_memory_metric::swap_free, threshold / 100,
+               e_memory_metric::swap_total, true, true);
          }},
         {"warning-swap-free-prct",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
-               e_status::warning, e_memory_metric::swap_free, threshold,
-               e_memory_metric::swap_total, true);
+               e_status::warning, e_memory_metric::swap_free, threshold / 100,
+               e_memory_metric::swap_total, true, true);
          }},
         // virtual memory
         {"critical-virtual",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
                e_status::critical, e_memory_metric::virtual_used, threshold,
-               e_memory_metric::virtual_total, false);
+               e_memory_metric::virtual_total, false, false);
          }},
         {"warning-virtual",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
                e_status::warning, e_memory_metric::virtual_used, threshold,
-               e_memory_metric::virtual_total, false);
+               e_memory_metric::virtual_total, false, false);
          }},
         {"critical-virtual-free",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
                e_status::critical, e_memory_metric::virtual_free, threshold,
-               e_memory_metric::virtual_total, false);
+               e_memory_metric::virtual_total, false, true);
          }},
         {"warning-virtual-free",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
                e_status::warning, e_memory_metric::virtual_free, threshold,
-               e_memory_metric::virtual_total, false);
+               e_memory_metric::virtual_total, false, true);
          }},
         {"critical-virtual-prct",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
-               e_status::critical, e_memory_metric::virtual_used, threshold,
-               e_memory_metric::virtual_total, true);
+               e_status::critical, e_memory_metric::virtual_used,
+               threshold / 100, e_memory_metric::virtual_total, true, false);
          }},
         {"warning-virtual-prct",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
-               e_status::warning, e_memory_metric::virtual_used, threshold,
-               e_memory_metric::virtual_total, true);
+               e_status::warning, e_memory_metric::virtual_used,
+               threshold / 100, e_memory_metric::virtual_total, true, false);
          }},
         {"critical-virtual-free-prct",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
-               e_status::critical, e_memory_metric::virtual_free, threshold,
-               e_memory_metric::virtual_total, true);
+               e_status::critical, e_memory_metric::virtual_free,
+               threshold / 100, e_memory_metric::virtual_total, true, true);
          }},
         {"warning-virtual-free-prct",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<windows_mem_to_status>(
-               e_status::warning, e_memory_metric::virtual_free, threshold,
-               e_memory_metric::virtual_total, true);
+               e_status::warning, e_memory_metric::virtual_free,
+               threshold / 100, e_memory_metric::virtual_total, true, true);
          }}
 
 };
@@ -360,10 +359,7 @@ static const absl::flat_hash_map<std::string_view, mem_to_status_constructor>
  * @param io_context
  * @param logger
  * @param first_start_expected
- * @param check_interval
  * @param serv
- * @param cmd_name
- * @param cmd_line
  * @param args
  * @param cnf
  * @param handler
@@ -371,10 +367,7 @@ static const absl::flat_hash_map<std::string_view, mem_to_status_constructor>
 check_memory::check_memory(const std::shared_ptr<asio::io_context>& io_context,
                            const std::shared_ptr<spdlog::logger>& logger,
                            time_point first_start_expected,
-                           duration check_interval,
-                           const std::string& serv,
-                           const std::string& cmd_name,
-                           const std::string& cmd_line,
+                           const Service& serv,
                            const rapidjson::Value& args,
                            const engine_to_agent_request_ptr& cnf,
                            check::completion_handler&& handler,
@@ -382,10 +375,7 @@ check_memory::check_memory(const std::shared_ptr<asio::io_context>& io_context,
     : native_check_base(io_context,
                         logger,
                         first_start_expected,
-                        check_interval,
                         serv,
-                        cmd_name,
-                        cmd_line,
                         args,
                         cnf,
                         std::move(handler),
@@ -396,16 +386,18 @@ check_memory::check_memory(const std::shared_ptr<asio::io_context>& io_context,
          ++member_iter) {
       std::string key = absl::AsciiStrToLower(member_iter->name.GetString());
       if (key == "swap") {
-        std::optional<bool> val = get_bool(
-            cmd_name, member_iter->name.GetString(), member_iter->value);
+        std::optional<bool> val =
+            get_bool(get_command_name(), member_iter->name.GetString(),
+                     member_iter->value);
         if (val && *val) {
           _output_flags |= w_memory_info::output_flags::dump_swap;
         }
         continue;
       }
       if (key == "virtual") {
-        std::optional<bool> val = get_bool(
-            cmd_name, member_iter->name.GetString(), member_iter->value);
+        std::optional<bool> val =
+            get_bool(get_command_name(), member_iter->name.GetString(),
+                     member_iter->value);
         if (val && *val) {
           _output_flags |= w_memory_info::output_flags::dump_virtual;
         }
@@ -414,20 +406,12 @@ check_memory::check_memory(const std::shared_ptr<asio::io_context>& io_context,
 
       auto mem_to_status_search = _label_to_mem_to_status.find(key);
       if (mem_to_status_search != _label_to_mem_to_status.end()) {
-        std::optional<std::string> val =
-            get_string(get_command_name(), member_iter->name.GetString(),
-                       member_iter->value);
+        std::optional<double> val =
+            get_double(get_command_name(), member_iter->name.GetString(),
+                       member_iter->value, true);
         if (val) {
-          common::threshold thr(val.value());
-          if (!thr.is_valid()) {
-            SPDLOG_LOGGER_ERROR(logger, "command: {}, invalid threshold: {}",
-                                get_command_name(), val.value());
-            throw exceptions::msg_fmt("command: {}, invalid threshold: {}",
-                                      get_command_name(), val.value());
-          }
-          thr.set_default_low(0);
           std::unique_ptr<windows_mem_to_status> mem_checker =
-              mem_to_status_search->second(thr);
+              mem_to_status_search->second(*val);
           _measure_to_status.emplace(
               std::make_tuple(mem_checker->get_data_index(),
                               mem_checker->get_total_data_index(),
@@ -436,7 +420,7 @@ check_memory::check_memory(const std::shared_ptr<asio::io_context>& io_context,
         }
       } else {
         SPDLOG_LOGGER_ERROR(logger, "command: {}, unknown parameter {}",
-                            cmd_name, member_iter->name);
+                            get_command_name(), member_iter->name);
       }
     }
   }
@@ -494,7 +478,7 @@ void check_memory::help(std::ostream& help_stream) {
     virtual (default false): true: add virtual memory to output
     critical-usage: threshold for critical status on physical memory usage in bytes
     warning-usage: threshold for warning status on physyical memory usage in bytes
-    critical-usage-free: threshold for critical status on free physical memory in bytes.
+    critical-usage-free: threshold for critical status on free physical memory in bytes, if free memory is lower than threshold, service is critical
     warning-usage-free: threshold for warning status on free physical memory in bytes
     critical-usage-prct: threshold for critical status on memory usage in percentage
     warning-usage-prct: threshold for warning status on memory usage in percentage
@@ -522,8 +506,8 @@ void check_memory::help(std::ostream& help_stream) {
     "args: {
       "swap": true,
       "virtual": true,
-      "warning-usage-prct": "80",
-      "critical-usage-prct": "90"
+      "warning-usage-prct": 80,
+      "critical-usage-prct": 90
     }
   }
   Examples of output:
