@@ -28,11 +28,22 @@ extern std::shared_ptr<asio::io_context> g_io_context;
 using namespace com::centreon::agent;
 using namespace std::string_literals;
 
+class counter_check_windows_test : public testing::Test {
+ public:
+  Service serv;
+
+  counter_check_windows_test() {
+    serv.set_service_description("serv");
+    serv.set_command_name("cmd_name");
+    serv.set_command_line("cmd_line");
+  }
+};
+
 /*
   Verify that the check_counter constructor works as expected.
   It should parse the JSON arguments and set the appropriate member variables.
 */
-TEST(counter_check_windows, constructor) {
+TEST_F(counter_check_windows_test, constructor) {
   using namespace com::centreon::common::literals;
   rapidjson::Document check_args =
       R"({"counter": "\\LogicalDisk(*)\\% Free Space",
@@ -41,8 +52,7 @@ TEST(counter_check_windows, constructor) {
     })"_json;
 
   check_counter checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, check_args, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, check_args, nullptr,
       []([[maybe_unused]] const std::shared_ptr<check>& caller,
          [[maybe_unused]] int status,
          [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -61,8 +71,7 @@ TEST(counter_check_windows, constructor) {
     "use_english": true
 })"_json;
   check_counter checker1(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, check_args1, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, check_args1, nullptr,
       []([[maybe_unused]] const std::shared_ptr<check>& caller,
          [[maybe_unused]] int status,
          [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -81,8 +90,7 @@ TEST(counter_check_windows, constructor) {
         "use_english": true
         })"_json;
   check_counter checker2(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, check_args2, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, check_args2, nullptr,
       []([[maybe_unused]] const std::shared_ptr<check>& caller,
          [[maybe_unused]] int status,
          [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -100,7 +108,7 @@ TEST(counter_check_windows, constructor) {
   Verify that the check_counter class can handle a single return value.
   It should correctly compute the status and output based on the counter value.
 */
-TEST(counter_check_windows, single_return) {
+TEST_F(counter_check_windows_test, single_return) {
   using namespace com::centreon::common::literals;
   rapidjson::Document check_args =
       R"({"counter": "\\System\\Processes",
@@ -110,8 +118,7 @@ TEST(counter_check_windows, single_return) {
     })"_json;
 
   check_counter checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, check_args, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, check_args, nullptr,
       []([[maybe_unused]] const std::shared_ptr<check>& caller,
          [[maybe_unused]] int status,
          [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -140,7 +147,7 @@ TEST(counter_check_windows, single_return) {
   It should correctly compute the status and output based on the counter value.
   also test warning status and warning count
 */
-TEST(counter_check_windows, multiple_return) {
+TEST_F(counter_check_windows_test, multiple_return) {
   using namespace com::centreon::common::literals;
   rapidjson::Document check_args =
       R"({"counter": "\\LogicalDisk(*)\\% Free Space",
@@ -151,8 +158,7 @@ TEST(counter_check_windows, multiple_return) {
     })"_json;
 
   check_counter checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, check_args, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, check_args, nullptr,
       []([[maybe_unused]] const std::shared_ptr<check>& caller,
          [[maybe_unused]] int status,
          [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -182,7 +188,7 @@ TEST(counter_check_windows, multiple_return) {
   samples. It should correctly compute the status and output based on the
   counter value. also test critical status and critical count
 */
-TEST(counter_check_windows, need_two_samples) {
+TEST_F(counter_check_windows_test, need_two_samples) {
   using namespace com::centreon::common::literals;
   rapidjson::Document check_args =
       R"({"counter": "\\Process V2(*)\\Thread Count",
@@ -192,8 +198,7 @@ TEST(counter_check_windows, need_two_samples) {
     })"_json;
 
   check_counter checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, check_args, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, check_args, nullptr,
       []([[maybe_unused]] const std::shared_ptr<check>& caller,
          [[maybe_unused]] int status,
          [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -227,7 +232,7 @@ TEST(counter_check_windows, need_two_samples) {
 */
 // Test if the warning status is correctly computed, and the output is well
 // formatted keywords tested: {status}, {problem-list}, {label}, {value}
-TEST(counter_check_windows, complex_rules) {
+TEST_F(counter_check_windows_test, complex_rules) {
   using namespace com::centreon::common::literals;
   rapidjson::Document check_args =
       R"({"counter": "\\Process V2(*)\\Thread Count",
@@ -240,8 +245,7 @@ TEST(counter_check_windows, complex_rules) {
     })"_json;
 
   check_counter checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, check_args, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, check_args, nullptr,
       []([[maybe_unused]] const std::shared_ptr<check>& caller,
          [[maybe_unused]] int status,
          [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -266,7 +270,7 @@ TEST(counter_check_windows, complex_rules) {
 }
 
 // test if the critical status is set
-TEST(counter_check_windows, complex_rules_2) {
+TEST_F(counter_check_windows_test, complex_rules_2) {
   using namespace com::centreon::common::literals;
   rapidjson::Document check_args =
       R"({"counter": "\\Process V2(*)\\Thread Count",
@@ -280,8 +284,7 @@ TEST(counter_check_windows, complex_rules_2) {
     })"_json;
 
   check_counter checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, check_args, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, check_args, nullptr,
       []([[maybe_unused]] const std::shared_ptr<check>& caller,
          [[maybe_unused]] int status,
          [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -306,7 +309,7 @@ TEST(counter_check_windows, complex_rules_2) {
 }
 // test the keywords {crit-list} and {warn-list} in the output-syntax
 // the label _total should be only in the crit-list and not in the warn-list
-TEST(counter_check_windows, complex_rules_3) {
+TEST_F(counter_check_windows_test, complex_rules_3) {
   using namespace com::centreon::common::literals;
   rapidjson::Document check_args =
       R"({"counter": "\\Process V2(*)\\Thread Count",
@@ -320,8 +323,7 @@ TEST(counter_check_windows, complex_rules_3) {
     })"_json;
 
   check_counter checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, check_args, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, check_args, nullptr,
       []([[maybe_unused]] const std::shared_ptr<check>& caller,
          [[maybe_unused]] int status,
          [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -345,7 +347,7 @@ TEST(counter_check_windows, complex_rules_3) {
 }
 
 // test the keywords {ok_list}
-TEST(counter_check_windows, complex_rules_4) {
+TEST_F(counter_check_windows_test, complex_rules_4) {
   using namespace com::centreon::common::literals;
   rapidjson::Document check_args =
       R"({"counter": "\\Process V2(*)\\Thread Count",
@@ -359,8 +361,7 @@ TEST(counter_check_windows, complex_rules_4) {
     })"_json;
 
   check_counter checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, check_args, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, check_args, nullptr,
       []([[maybe_unused]] const std::shared_ptr<check>& caller,
          [[maybe_unused]] int status,
          [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -389,7 +390,7 @@ TEST(counter_check_windows, complex_rules_4) {
 
 // test the keywords {warn-count},{crit-count},{ok-count},{problem-count} and
 // {total} in the output-syntax
-TEST(counter_check_windows, complex_rules_5) {
+TEST_F(counter_check_windows_test, complex_rules_5) {
   using namespace com::centreon::common::literals;
   rapidjson::Document check_args =
       R"({"counter": "\\Process V2(*)\\Thread Count",
@@ -404,8 +405,7 @@ TEST(counter_check_windows, complex_rules_5) {
     })"_json;
 
   check_counter checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, check_args, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, check_args, nullptr,
       []([[maybe_unused]] const std::shared_ptr<check>& caller,
          [[maybe_unused]] int status,
          [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -429,7 +429,7 @@ TEST(counter_check_windows, complex_rules_5) {
 
 // test the keywords {warn-list} and {crit-list} and also the count for critical
 // status
-TEST(counter_check_windows, complex_rules_6) {
+TEST_F(counter_check_windows_test, complex_rules_6) {
   using namespace com::centreon::common::literals;
   rapidjson::Document check_args =
       R"({"counter": "\\Process V2(*)\\Thread Count",
@@ -438,14 +438,13 @@ TEST(counter_check_windows, complex_rules_6) {
         "detail-syntax": "{label}",
         "warning-status": "value >= 20",
         "critical-status": "value >= 42",
-        "warning-count": "",
-        "critical-count": "1",
+        "warning-count": "0",
+        "critical-count": "2",
         "use_english": true
     })"_json;
 
   check_counter checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, check_args, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, check_args, nullptr,
       []([[maybe_unused]] const std::shared_ptr<check>& caller,
          [[maybe_unused]] int status,
          [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -470,7 +469,7 @@ TEST(counter_check_windows, complex_rules_6) {
   ASSERT_EQ(perf.size(), 12);
 }
 // test the complex rultes for warning
-TEST(counter_check_windows, complex_rules_7) {
+TEST_F(counter_check_windows_test, complex_rules_7) {
   using namespace com::centreon::common::literals;
   rapidjson::Document check_args =
       R"({"counter": "\\Process V2(*)\\Thread Count",
@@ -485,8 +484,7 @@ TEST(counter_check_windows, complex_rules_7) {
     })"_json;
 
   check_counter checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, check_args, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, check_args, nullptr,
       []([[maybe_unused]] const std::shared_ptr<check>& caller,
          [[maybe_unused]] int status,
          [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -509,7 +507,7 @@ TEST(counter_check_windows, complex_rules_7) {
 }
 
 // test the complex rules for critical status
-TEST(counter_check_windows, complex_rules_8) {
+TEST_F(counter_check_windows_test, complex_rules_8) {
   using namespace com::centreon::common::literals;
   rapidjson::Document check_args =
       R"({"counter": "\\Process V2(*)\\Thread Count",
@@ -518,13 +516,12 @@ TEST(counter_check_windows, complex_rules_8) {
         "detail-syntax": "{label}",
         "warning-status": "",
         "critical-status": "chrome >= 150 || firefox >= 150 || svchost >= 20",
-        "critical-count": "0",
+        "critical-count": "1",
         "use_english": true
     })"_json;
 
   check_counter checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, check_args, nullptr,
+      g_io_context, spdlog::default_logger(), {}, serv, check_args, nullptr,
       []([[maybe_unused]] const std::shared_ptr<check>& caller,
          [[maybe_unused]] int status,
          [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -544,160 +541,4 @@ TEST(counter_check_windows, complex_rules_8) {
   std::list<com::centreon::common::perfdata> perf;
   checker.compute(&output, &perf);
   ASSERT_EQ(output, "CRITICAL: Warn : --- crit : svchost");
-}
-
-// test the threshold
-TEST(counter_check_windows, threshold_greater) {
-  using namespace com::centreon::common::literals;
-  rapidjson::Document check_args =
-      R"({"counter": "\\Process V2(*)\\Thread Count",
-        "counter-filter":"any",
-        "output-syntax": "${status}: Warn :{warn-list} --- crit : {crit-list}",
-        "detail-syntax": "{label}",
-        "warning-status": "",
-        "critical-status": "chrome >= 40 || firefox >= 150 || svchost >= 20 || explorer>=15",
-        "critical-count": "2",
-        "use_english": true
-    })"_json;
-
-  check_counter checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, check_args, nullptr,
-      []([[maybe_unused]] const std::shared_ptr<check>& caller,
-         [[maybe_unused]] int status,
-         [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
-             perfdata,
-         [[maybe_unused]] const std::list<std::string>& outputs) {},
-      std::make_shared<checks_statistics>());
-
-  absl::flat_hash_map<std::string, double> data = {
-      {"_total", 150.0},  {"svchost", 24.0}, {"explorer", 18.0},
-      {"chrome", 42.0},   {"firefox", 36.0}, {"notepad", 5.0},
-      {"winlogon", 12.0}, {"lsass", 16.0},   {"services", 28.0},
-      {"csrss", 10.0}};
-
-  checker.set_counter_data(data);
-
-  std::string output;
-  std::list<com::centreon::common::perfdata> perf;
-  auto status = checker.compute(&output, &perf);
-  ASSERT_EQ(status, e_status::critical);
-}
-
-// test the threshold
-TEST(counter_check_windows, threshold_range) {
-  using namespace com::centreon::common::literals;
-  rapidjson::Document check_args =
-      R"({"counter": "\\Process V2(*)\\Thread Count",
-        "counter-filter":"any",
-        "output-syntax": "${status}: Warn :{warn-list} --- crit : {crit-list}",
-        "detail-syntax": "{label}",
-        "warning-status": "",
-        "critical-status": "chrome >= 40 || firefox >= 150 || svchost >= 20 || explorer>=15",
-        "critical-count": "2:5",
-        "use_english": true
-    })"_json;
-
-  check_counter checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, check_args, nullptr,
-      []([[maybe_unused]] const std::shared_ptr<check>& caller,
-         [[maybe_unused]] int status,
-         [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
-             perfdata,
-         [[maybe_unused]] const std::list<std::string>& outputs) {},
-      std::make_shared<checks_statistics>());
-
-  absl::flat_hash_map<std::string, double> data = {
-      {"_total", 150.0},  {"svchost", 24.0}, {"explorer", 18.0},
-      {"chrome", 42.0},   {"firefox", 36.0}, {"notepad", 5.0},
-      {"winlogon", 12.0}, {"lsass", 16.0},   {"services", 28.0},
-      {"csrss", 10.0}};
-
-  checker.set_counter_data(data);
-
-  std::string output;
-  std::list<com::centreon::common::perfdata> perf;
-  auto status = checker.compute(&output, &perf);
-  ASSERT_EQ(status, e_status::ok);  // ok because the critical count is 3 and it
-                                    // inside the range 2:5
-}
-
-// test the threshold
-TEST(counter_check_windows, threshold_inside_range) {
-  using namespace com::centreon::common::literals;
-  rapidjson::Document check_args =
-      R"({"counter": "\\Process V2(*)\\Thread Count",
-        "counter-filter":"any",
-        "output-syntax": "${status}: Warn :{warn-list} --- crit : {crit-list}",
-        "detail-syntax": "{label}",
-        "warning-status": "",
-        "critical-status": "chrome >= 40 || firefox >= 150 || svchost >= 20 || explorer>=15",
-        "critical-count": "@2:5",
-        "use_english": true
-    })"_json;
-
-  check_counter checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, check_args, nullptr,
-      []([[maybe_unused]] const std::shared_ptr<check>& caller,
-         [[maybe_unused]] int status,
-         [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
-             perfdata,
-         [[maybe_unused]] const std::list<std::string>& outputs) {},
-      std::make_shared<checks_statistics>());
-
-  absl::flat_hash_map<std::string, double> data = {
-      {"_total", 150.0},  {"svchost", 24.0}, {"explorer", 18.0},
-      {"chrome", 42.0},   {"firefox", 36.0}, {"notepad", 5.0},
-      {"winlogon", 12.0}, {"lsass", 16.0},   {"services", 28.0},
-      {"csrss", 10.0}};
-
-  checker.set_counter_data(data);
-
-  std::string output;
-  std::list<com::centreon::common::perfdata> perf;
-  auto status = checker.compute(&output, &perf);
-  ASSERT_EQ(status,
-            e_status::critical);  // crit because the critical count is 3 and it
-                                  // inside the range 2:5 and use @
-}
-
-TEST(counter_check_windows, threshold_below) {
-  using namespace com::centreon::common::literals;
-  rapidjson::Document check_args =
-      R"({"counter": "\\Process V2(*)\\Thread Count",
-        "counter-filter":"any",
-        "output-syntax": "${status}: Warn :{warn-list} --- crit : {crit-list}",
-        "detail-syntax": "{label}",
-        "warning-status": "",
-        "critical-status": "chrome >= 40 || firefox >= 150 || svchost >= 20 || explorer>=15",
-        "critical-count": "2:",
-        "use_english": true
-    })"_json;
-
-  check_counter checker(
-      g_io_context, spdlog::default_logger(), {}, {}, "serv"s, "cmd_name"s,
-      "cmd_line"s, check_args, nullptr,
-      []([[maybe_unused]] const std::shared_ptr<check>& caller,
-         [[maybe_unused]] int status,
-         [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
-             perfdata,
-         [[maybe_unused]] const std::list<std::string>& outputs) {},
-      std::make_shared<checks_statistics>());
-
-  absl::flat_hash_map<std::string, double> data = {
-      {"_total", 150.0},  {"svchost", 24.0}, {"explorer", 18.0},
-      {"chrome", 42.0},   {"firefox", 36.0}, {"notepad", 5.0},
-      {"winlogon", 12.0}, {"lsass", 16.0},   {"services", 28.0},
-      {"csrss", 10.0}};
-
-  checker.set_counter_data(data);
-
-  std::string output;
-  std::list<com::centreon::common::perfdata> perf;
-  auto status = checker.compute(&output, &perf);
-  ASSERT_EQ(status,
-            e_status::ok);  // ok because the critical count is 3 and it
-                            // higher than 2 , the lower bound 2:
 }
\ No newline at end of file
