@@ -18,12 +18,6 @@
 
 #include "com/centreon/broker/bam/ba.hh"
 
-#include <fmt/format.h>
-
-#include <cassert>
-
-#include "bbdo/neb.pb.h"
-#include "com/centreon/broker/bam/impact_values.hh"
 #include "com/centreon/broker/bam/kpi.hh"
 #include "com/centreon/broker/config/applier/state.hh"
 #include "com/centreon/broker/neb/downtime.hh"
@@ -269,11 +263,10 @@ void ba::visit(io::stream* visitor) {
       SPDLOG_LOGGER_TRACE(
           _logger,
           "BAM: ba current event needs update? downtime?: {}, state?: {} ; "
-          "dt:{}, state:{} from {}",
+          "dt:{}, state:{} ",
           _in_downtime != _event->obj().in_downtime(),
           com::centreon::broker::State(hard_state) != _event->obj().status(),
-          _in_downtime, static_cast<uint32_t>(hard_state),
-          _event->obj().start_time());
+          _in_downtime, static_cast<uint32_t>(hard_state));
       state_changed = true;
       _event->mut_obj().set_end_time(_last_kpi_update);
       visitor->write(std::static_pointer_cast<io::data>(_event));
@@ -346,19 +339,20 @@ void ba::service_update(const std::shared_ptr<neb::pb_downtime>& dt,
   assert(downtime.host_id() == _host_id &&
          downtime.service_id() == _service_id);
 
-  // Log message.
-  SPDLOG_LOGGER_DEBUG(
-      _logger,
-      "BAM: BA {} '{}' is getting notified of a downtime (pb) on its service "
-      "({}, {})",
-      _id, _name, _host_id, _service_id);
-
   // Check if there was a change.
   bool in_downtime(downtime.started() &&
                    time_is_undefined(downtime.actual_end_time()));
+
+  // Log message.
+  SPDLOG_LOGGER_DEBUG(
+      _logger,
+      "BAM: BA {} '{}' is getting notified of a pb downtime {} on its service "
+      "({}, {}) in downtime {}",
+      _id, _name, downtime.id(), _host_id, _service_id, in_downtime);
+
   if (_in_downtime != in_downtime) {
-    SPDLOG_LOGGER_TRACE(_logger, "ba: service_update downtime: {}",
-                        _in_downtime);
+    SPDLOG_LOGGER_TRACE(_logger, "ba: service_update downtime: from {} to {}",
+                        _in_downtime, in_downtime);
     _in_downtime = in_downtime;
 
     // Generate status event.
@@ -373,11 +367,8 @@ void ba::service_update(const std::shared_ptr<neb::pb_downtime>& dt,
  *
  *  @param[in] cache  The cache.
  */
-void ba::save_inherited_downtime(persistent_cache& cache) const {
-  if (_inherited_downtime)
-    cache.add(
-        std::make_shared<pb_inherited_downtime>(_inherited_downtime->obj()));
-}
+void ba::save_inherited_downtime(persistent_cache& cache
+                                 [[maybe_unused]]) const {}
 
 /**
  *  Set the inherited downtime of this ba.
@@ -411,11 +402,8 @@ void ba::set_inherited_downtime(const inherited_downtime& dwn) {
  */
 void ba::_open_new_event(io::stream* visitor,
                          com::centreon::broker::bam::state service_hard_state) {
-  SPDLOG_LOGGER_TRACE(
-      _logger,
-      "new pb_ba_event on ba {}  with status {}, downtime = {} from {}", _id,
-      com::centreon::broker::bam::state_str[service_hard_state], _in_downtime,
-      _last_kpi_update.get_time_t());
+  SPDLOG_LOGGER_TRACE(_logger, "new pb_ba_event on ba {} with downtime = {}",
+                      _id, _in_downtime);
   _event = std::make_shared<pb_ba_event>();
   BaEvent& data = _event->mut_obj();
   data.set_ba_id(_id);
