@@ -35,7 +35,6 @@
 using namespace com::centreon::broker;
 using log_v2 = com::centreon::common::log_v2::log_v2;
 
-
 class BamExpBuilder : public ::testing::Test {
  protected:
   std::unique_ptr<test_visitor> _visitor;
@@ -45,7 +44,7 @@ class BamExpBuilder : public ::testing::Test {
   void SetUp() override {
     _logger = log_v2::instance().get(log_v2::BAM);
     try {
-      config::applier::init(0, "test_broker", 0);
+      config::applier::init(com::centreon::common::BROKER, 0, "test_broker", 0);
       _logger->set_level(spdlog::level::debug);
       _logger->flush_on(spdlog::level::debug);
     } catch (std::exception const& e) {
