@@ -16,19 +16,16 @@
  * For more information : contact@centreon.com
  */
 
-#include "com/centreon/broker/multiplexing/muxer.hh"
-#include <absl/synchronization/mutex.h>
 #include <absl/time/time.h>
 
 #include <cassert>
 
-#include "com/centreon/broker/bbdo/internal.hh"
+#include "broker/core/bbdo/internal.hh"
 #include "com/centreon/broker/config/applier/state.hh"
 #include "com/centreon/broker/exceptions/shutdown.hh"
 #include "com/centreon/broker/io/events.hh"
 #include "com/centreon/broker/misc/misc.hh"
 #include "com/centreon/broker/misc/string.hh"
-#include "com/centreon/broker/multiplexing/engine.hh"
 #include "com/centreon/common/pool.hh"
 #include "com/centreon/common/time.hh"
 #include "common/log_v2/log_v2.hh"
@@ -59,6 +56,9 @@ static void add_bench_point(bbdo::pb_bench& event,
 
 uint32_t muxer::_event_queue_max_size = std::numeric_limits<uint32_t>::max();
 
+absl::Mutex muxer::_running_muxers_m;
+absl::flat_hash_map<std::string, std::weak_ptr<muxer>> muxer::_running_muxers;
+
 /**
  * @brief Constructor.
  *
@@ -87,7 +87,7 @@ muxer::muxer(std::string name,
       _write_filters_str{misc::dump_filters(w_filter)},
       _persistent(persistent),
       _events_size{0u},
-      _center{stats::center::instance_ptr()},
+      _center{config::applier::state::instance().center()},
       _last_stats{std::time(nullptr)},
       _logger{log_v2::instance().get(log_v2::CORE)} {
   absl::SetMutexDeadlockDetectionMode(absl::OnDeadlockCycle::kAbort);
@@ -165,7 +165,12 @@ std::shared_ptr<muxer> muxer::create(std::string name,
                                      bool persistent) {
   std::shared_ptr<muxer> retval;
   {
-    retval = parent->get_muxer(name);
+    absl::MutexLock lck(&_running_muxers_m);
+    absl::erase_if(_running_muxers,
+                   [](const std::pair<std::string, std::weak_ptr<muxer>>& p) {
+                     return p.second.expired();
+                   });
+    retval = _running_muxers[name].lock();
     if (retval) {
       log_v2::instance()
           .get(log_v2::CONFIG)
@@ -184,7 +189,7 @@ std::shared_ptr<muxer> muxer::create(std::string name,
           ->debug("muxer: muxer '{}' unknown, creating it", name);
       retval = std::shared_ptr<muxer>(
           new muxer(name, parent, r_filter, w_filter, persistent));
-      parent->set_muxer(name, retval);
+      _running_muxers[name] = retval;
     }
   }
 
@@ -307,32 +312,32 @@ void muxer::_execute_reader_if_needed() {
       _logger, "muxer '{}' execute reader if needed data_handler", _name);
   bool expected = false;
   if (_reader_running.compare_exchange_strong(expected, true)) {
-    asio::post(*com::centreon::common::pool::io_context_ptr(),
-               [me = shared_from_this(), this] {
-                 std::shared_ptr<data_handler> to_call;
-                 {
-                   absl::MutexLock lck(&_events_m);
-                   to_call = _data_handler;
-                 }
-                 if (to_call) {
-                   std::vector<std::shared_ptr<io::data>> to_fill;
-                   to_fill.reserve(_events_size);
-                   bool still_events_to_read [[maybe_unused]] =
-                       read(to_fill, _events_size);
-                   uint32_t written = to_call->on_events(to_fill);
-                   if (written > 0)
-                     ack_events(written);
-                   if (written != to_fill.size()) {
-                     SPDLOG_LOGGER_ERROR(
-                         _logger,
-                         "Unable to handle all the incoming events in "
-                         "muxer '{}'",
-                         _name);
-                     clear_action_on_new_data();
-                   }
-                   _reader_running.store(false);
-                 }
-               });
+    asio::post(
+        *com::centreon::common::pool::io_context_ptr(),
+        [me = shared_from_this(), this] {
+          std::shared_ptr<data_handler> to_call;
+          {
+            absl::MutexLock lck(&_events_m);
+            to_call = _data_handler;
+          }
+          if (to_call) {
+            std::vector<std::shared_ptr<io::data>> to_fill;
+            to_fill.reserve(_events_size);
+            bool still_events_to_read [[maybe_unused]] =
+                read(to_fill, _events_size);
+            uint32_t written = to_call->on_events(to_fill);
+            if (written > 0)
+              ack_events(written);
+            if (written != to_fill.size()) {
+              SPDLOG_LOGGER_ERROR(
+                  _logger,
+                  "Unable to handle all the incoming events in muxer '{}'",
+                  _name);
+              clear_action_on_new_data();
+            }
+            _reader_running.store(false);
+          }
+        });
   }
 }
 
