@@ -21,15 +21,8 @@
 #include <cassert>
 
 #include "com/centreon/broker/config/applier/state.hh"
-#include "com/centreon/broker/io/endpoint.hh"
 #include "com/centreon/broker/io/events.hh"
 #include "com/centreon/broker/io/protocols.hh"
-#include "com/centreon/broker/misc/misc.hh"
-#include "com/centreon/broker/multiplexing/engine.hh"
-#include "com/centreon/broker/multiplexing/muxer.hh"
-#include "com/centreon/broker/persistent_cache.hh"
-#include "com/centreon/broker/processing/acceptor.hh"
-#include "com/centreon/broker/processing/endpoint.hh"
 #include "com/centreon/broker/processing/failover.hh"
 #include "com/centreon/exceptions/msg_fmt.hh"
 #include "common/log_v2/log_v2.hh"
@@ -100,7 +93,8 @@ endpoint::~endpoint() {
  *
  *  @param[in] endpoints  Endpoints configuration objects.
  */
-void endpoint::apply(std::list<config::endpoint> const& endpoints) {
+void endpoint::apply(std::list<config::endpoint> const& endpoints,
+                     const std::map<std::string, std::string>& global_params) {
   // Log messages.
   SPDLOG_LOGGER_INFO(_logger, "endpoint applier: loading configuration");
 
@@ -116,14 +110,6 @@ void endpoint::apply(std::list<config::endpoint> const& endpoints) {
   // Copy endpoint configurations and apply eventual modifications.
   std::list<config::endpoint> tmp_endpoints(endpoints);
 
-  // we apply default fields value to each endpoint
-  for (config::endpoint& endp : tmp_endpoints) {
-    for (const auto& protocol : io::protocols::instance()) {
-      if (protocol.second.endpntfactry->has_endpoint(endp, nullptr))
-        protocol.second.endpntfactry->set_default_values(endp);
-    }
-  }
-
   // Remove old inputs and generate inputs to create.
   std::list<config::endpoint> endp_to_create;
   {
@@ -170,19 +156,22 @@ void endpoint::apply(std::list<config::endpoint> const& endpoints) {
       SPDLOG_LOGGER_DEBUG(_logger, "endpoint applier: creating endpoint {}",
                           ep.name);
       bool is_acceptor;
-      std::shared_ptr<io::endpoint> e{_create_endpoint(ep, is_acceptor)};
+      std::shared_ptr<io::endpoint> e{
+          _create_endpoint(ep, global_params, is_acceptor)};
       std::unique_ptr<processing::endpoint> endp;
       /* Input or output? */
       /* This is tricky, one day we will make better... I hope.
-       * In case of an Engine making connection to Broker, usually Broker is
-       * an acceptor and Engine not. In case of one peer retention, each one
-       * keeps its role but the connection is reversed. To keep this behavior,
-       * Engine is still considered as the connector and Broker the acceptor,
-       * is_acceptor is then set to false. In case of Broker connected to Map,
-       * Broker is a TCP acceptor, and this flag is returned as true. And then
-       * we create an acceptor even if broker sends data to map. This is
-       * needed because a failover needs its peer to ack events to release
-       * them (and a failover is also able to write data). */
+       * In case of an Engine making connection to Broker, usually Broker is an
+       * acceptor and Engine not.
+       * In case of one peer retention, each one keeps its role but the
+       * connection is reversed. To keep this behavior, Engine is still
+       * considered as the connector and Broker the acceptor, is_acceptor is
+       * then set to false.
+       * In case of Broker connected to Map, Broker is a TCP acceptor, and
+       * this flag is returned as true. And then we create an acceptor even
+       * if broker sends data to map. This is needed because a failover needs
+       * its peer to ack events to release them (and a failover is also able
+       * to write data). */
       multiplexing::muxer_filter r_filter =
           parse_filters(ep.read_filters, e->get_stream_forbidden_filter());
       multiplexing::muxer_filter w_filter =
@@ -193,12 +182,12 @@ void endpoint::apply(std::list<config::endpoint> const& endpoints) {
         std::unique_ptr<processing::acceptor> acceptr(
             std::make_unique<processing::acceptor>(e, ep.name, r_filter,
                                                    w_filter));
-        SPDLOG_LOGGER_DEBUG(_logger,
-                            "endpoint applier: acceptor '{}' configured with "
-                            "write filters: {} "
-                            "and read filters: {}",
-                            ep.name, w_filter.get_allowed_categories(),
-                            r_filter.get_allowed_categories());
+        SPDLOG_LOGGER_DEBUG(
+            _logger,
+            "endpoint applier: acceptor '{}' configured with write filters: {} "
+            "and read filters: {}",
+            ep.name, w_filter.get_allowed_categories(),
+            r_filter.get_allowed_categories());
         endp.reset(acceptr.release());
       } else {
         // Create muxer and endpoint.
@@ -208,8 +197,7 @@ void endpoint::apply(std::list<config::endpoint> const& endpoints) {
           w_filter |= e->get_stream_mandatory_filter();
           SPDLOG_LOGGER_DEBUG(
               _logger,
-              "endpoint applier: The configured write filters for the "
-              "endpoint "
+              "endpoint applier: The configured write filters for the endpoint "
               "'{}' are too restrictive. Mandatory categories added to them",
               ep.name);
         }
@@ -218,8 +206,7 @@ void endpoint::apply(std::list<config::endpoint> const& endpoints) {
           w_filter -= e->get_stream_forbidden_filter();
           SPDLOG_LOGGER_ERROR(
               _logger,
-              "endpoint applier: The configured write filters for the "
-              "endpoint "
+              "endpoint applier: The configured write filters for the endpoint "
               "'{}' contain forbidden filters. These ones are removed",
               ep.name);
         }
@@ -229,8 +216,7 @@ void endpoint::apply(std::list<config::endpoint> const& endpoints) {
           r_filter -= e->get_stream_forbidden_filter();
           SPDLOG_LOGGER_ERROR(
               _logger,
-              "endpoint applier: The configured read filters for the "
-              "endpoint "
+              "endpoint applier: The configured read filters for the endpoint "
               "'{}' contain forbidden filters. These ones are removed",
               ep.name);
         }
@@ -241,7 +227,7 @@ void endpoint::apply(std::list<config::endpoint> const& endpoints) {
         auto mux = multiplexing::muxer::create(
             ep.name, multiplexing::engine::instance_ptr(), r_filter, w_filter,
             true);
-        endp.reset(_create_failover(ep, mux, e, endp_to_create));
+        endp.reset(_create_failover(ep, global_params, mux, e, endp_to_create));
       }
       {
         std::lock_guard<std::timed_mutex> lock(_endpointsm);
@@ -394,6 +380,7 @@ void endpoint::unload() {
  */
 processing::failover* endpoint::_create_failover(
     config::endpoint& cfg,
+    const std::map<std::string, std::string>& global_params,
     std::shared_ptr<multiplexing::muxer> mux,
     std::shared_ptr<io::endpoint> endp,
     std::list<config::endpoint>& l) {
@@ -414,14 +401,15 @@ processing::failover* endpoint::_create_failover(
           front_failover, cfg.name);
     else {
       bool is_acceptor;
-      std::shared_ptr<io::endpoint> e(_create_endpoint(*it, is_acceptor));
+      std::shared_ptr<io::endpoint> e(
+          _create_endpoint(*it, global_params, is_acceptor));
       if (is_acceptor)
         throw msg_fmt(
             "endpoint applier: cannot allow acceptor '{}' as failover for "
             "endpoint '{}'",
             front_failover, cfg.name);
       failovr = std::shared_ptr<processing::failover>(
-          _create_failover(*it, mux, e, l));
+          _create_failover(*it, global_params, mux, e, l));
 
       // Add secondary failovers
       for (std::list<std::string>::const_iterator
@@ -436,7 +424,8 @@ processing::failover* endpoint::_create_failover(
               "endpoint '{}'",
               *failover_it, cfg.name);
         bool is_acceptor{false};
-        std::shared_ptr<io::endpoint> endp(_create_endpoint(*it, is_acceptor));
+        std::shared_ptr<io::endpoint> endp(
+            _create_endpoint(*it, global_params, is_acceptor));
         if (is_acceptor) {
           SPDLOG_LOGGER_ERROR(
               _logger,
@@ -465,8 +454,10 @@ processing::failover* endpoint::_create_failover(
  *
  *  @return A new endpoint.
  */
-std::shared_ptr<io::endpoint> endpoint::_create_endpoint(config::endpoint& cfg,
-                                                         bool& is_acceptor) {
+std::shared_ptr<io::endpoint> endpoint::_create_endpoint(
+    config::endpoint& cfg,
+    const std::map<std::string, std::string>& global_params,
+    bool& is_acceptor) {
   // Create endpoint object.
   std::shared_ptr<io::endpoint> endp;
   int level{0};
@@ -488,8 +479,9 @@ std::shared_ptr<io::endpoint> endpoint::_create_endpoint(config::endpoint& cfg,
             log_v2::instance().get(log_id));
       }
 
-      endp = std::shared_ptr<io::endpoint>(
-          it->second.endpntfactry->new_endpoint(cfg, is_acceptor, cache));
+      endp =
+          std::shared_ptr<io::endpoint>(it->second.endpntfactry->new_endpoint(
+              cfg, global_params, is_acceptor, cache));
       SPDLOG_LOGGER_INFO(_logger, " create endpoint {} for endpoint '{}'",
                          it->first, cfg.name);
       level = it->second.osi_to + 1;
@@ -511,7 +503,8 @@ std::shared_ptr<io::endpoint> endpoint::_create_endpoint(config::endpoint& cfg,
       if ((it->second.osi_from == level) &&
           (it->second.endpntfactry->has_endpoint(cfg, nullptr))) {
         std::shared_ptr<io::endpoint> current(
-            it->second.endpntfactry->new_endpoint(cfg, is_acceptor));
+            it->second.endpntfactry->new_endpoint(cfg, global_params,
+                                                  is_acceptor));
         SPDLOG_LOGGER_INFO(_logger, " create endpoint {} for endpoint '{}'",
                            it->first, cfg.name);
         current->from(endp);
