@@ -134,8 +134,8 @@ bool endpoint::operator<(const endpoint& other) const {
     return cfg < other.cfg;
 
   // Need to check all parameters one by one.
-  std::map<std::string, std::string>::const_iterator it1{params.begin()},
-      it2{other.params.begin()}, end1{params.end()}, end2{other.params.end()};
+  auto it1 = params.begin(), it2 = other.params.begin(), end1 = params.end(),
+       end2 = other.params.end();
   while (it1 != end1 && it2 != end2) {
     if (it1->first != it2->first)
       return it1->first < it2->first;
