@@ -22,7 +22,6 @@
 
 #include <absl/strings/match.h>
 #include <absl/strings/str_split.h>
-#include <streambuf>
 
 #include "com/centreon/broker/exceptions/deprecated.hh"
 #include "com/centreon/broker/misc/filesystem.hh"
@@ -149,11 +148,10 @@ absl::optional<std::string> parser::check_and_read<std::string>(
  *  Parse a configuration file.
  *
  *  @param[in]  file File to process.
- *  @param[in]  neb_module true if we are in case of neb module
  *
  *  @return a state corresponding to the json file processed.
  */
-state parser::parse(std::string const& file, bool neb_module) {
+state parser::parse(std::string const& file) {
   state retval;
   // Parse JSON document.
   std::ifstream f(file);
@@ -264,6 +262,21 @@ state parser::parse(std::string const& file, bool neb_module) {
           if (!misc::filesystem::readable(retval.cache_directory()))
             throw msg_fmt("The cache directory '{}' is not accessible",
                           retval.cache_directory());
+        } else if (get_conf<state>(
+                       {it.key(), it.value()}, "cache_config_directory", retval,
+                       &state::set_config_cache_dir, &json::is_string)) {
+          if (!misc::filesystem::readable(retval.config_cache_dir()))
+            throw msg_fmt(
+                "The cache configuration directory '{}' is not accessible",
+                retval.config_cache_dir());
+        } else if (get_conf<state>({it.key(), it.value()},
+                                   "pollers_config_directory", retval,
+                                   &state::set_pollers_config_dir,
+                                   &json::is_string)) {
+          if (!misc::filesystem::readable(retval.pollers_config_dir()))
+            throw msg_fmt(
+                "The pollers configuration directory '{}' is not accessible",
+                retval.pollers_config_dir());
         } else if (get_conf<int, state>({it.key(), it.value()}, "pool_size",
                                         retval, &state::pool_size,
                                         &json::is_number, &json::get<int>))
@@ -358,62 +371,54 @@ state parser::parse(std::string const& file, bool neb_module) {
             throw msg_fmt("the log configuration should be a json object");
 
           auto& conf = retval.mut_log_conf();
-          // In case of neb used by centengine, many logs parameters are yet set
-          // by engine configuration
-          if (!neb_module) {
-            if (conf_js.contains("directory") &&
-                conf_js["directory"].is_string())
-              conf.set_dirname(conf_js["directory"].get<std::string>());
-            else if (conf_js.contains("directory") &&
-                     !conf_js["directory"].is_null())
+          if (conf_js.contains("directory") && conf_js["directory"].is_string())
+            conf.set_dirname(conf_js["directory"].get<std::string>());
+          else if (conf_js.contains("directory") &&
+                   !conf_js["directory"].is_null())
+            throw msg_fmt(
+                "'directory' key in the log configuration must contain a "
+                "directory name");
+          if (conf.dirname().empty())
+            conf.set_dirname("/var/log/centreon-broker");
+
+          if (!misc::filesystem::writable(conf.dirname()))
+            throw msg_fmt("The log directory '{}' is not writable",
+                          conf.dirname());
+
+          conf.set_filename("");
+
+          if (conf_js.contains("filename") && conf_js["filename"].is_string()) {
+            conf.set_filename(conf_js["filename"].get<std::string>());
+            if (conf.filename().find("/") != std::string::npos)
               throw msg_fmt(
-                  "'directory' key in the log configuration must contain a "
-                  "directory name");
-            if (conf.dirname().empty())
-              conf.set_dirname("/var/log/centreon-broker");
+                  "'filename' must only contain a filename without directory");
 
-            if (!misc::filesystem::writable(conf.dirname()))
-              throw msg_fmt("The log directory '{}' is not writable",
-                            conf.dirname());
+          } else if (conf_js.contains("filename") &&
+                     !conf_js["filename"].is_null())
+            throw msg_fmt(
+                "'filename' key in the log configuration must contain the log "
+                "file name");
 
-            conf.set_filename("");
+          auto ms = check_and_read<int64_t>(conf_js, "max_size");
+          conf.set_max_size(ms ? ms.value() : 0u);
 
-            if (conf_js.contains("filename") &&
-                conf_js["filename"].is_string()) {
-              conf.set_filename(conf_js["filename"].get<std::string>());
-              if (conf.filename().find("/") != std::string::npos)
-                throw msg_fmt(
-                    "'filename' must only contain a filename without "
-                    "directory");
-
-            } else if (conf_js.contains("filename") &&
-                       !conf_js["filename"].is_null())
+          auto fp = check_and_read<int64_t>(conf_js, "flush_period");
+          if (fp) {
+            if (fp.value() < 0)
               throw msg_fmt(
-                  "'filename' key in the log configuration must contain the "
-                  "log "
-                  "file name");
+                  "'flush_period' key in the log configuration must contain a "
+                  "positive number or 0.");
 
-            auto ms = check_and_read<int64_t>(conf_js, "max_size");
-            conf.set_max_size(ms ? ms.value() : 0u);
+            conf.set_flush_interval(fp.value());
+          } else
+            conf.set_flush_interval(0u);
 
-            auto fp = check_and_read<int64_t>(conf_js, "flush_period");
-            if (fp) {
-              if (fp.value() < 0)
-                throw msg_fmt(
-                    "'flush_period' key in the log configuration must contain "
-                    "a "
-                    "positive number or 0.");
+          auto lp = check_and_read<bool>(conf_js, "log_pid");
+          conf.set_log_pid(lp ? lp.value() : false);
 
-              conf.set_flush_interval(fp.value());
-            } else
-              conf.set_flush_interval(0u);
+          auto ls = check_and_read<bool>(conf_js, "log_source");
+          conf.set_log_source(ls ? ls.value() : false);
 
-            auto lp = check_and_read<bool>(conf_js, "log_pid");
-            conf.set_log_pid(lp ? lp.value() : false);
-
-            auto ls = check_and_read<bool>(conf_js, "log_source");
-            conf.set_log_source(ls ? ls.value() : false);
-          }
           if (conf_js.contains("loggers") && conf_js["loggers"].is_object()) {
             conf.loggers().clear();
             for (auto it = conf_js["loggers"].begin();
@@ -500,7 +505,10 @@ state parser::parse(std::string const& file, bool neb_module) {
           if (it.key() == "stats")
             retval.add_module("15-stats.so");
 
-          retval.params()[it.key()] = it.value().dump();
+          if (it.value().is_string())
+            retval.params()[it.key()] = it.value().get<std::string>();
+          else
+            retval.params()[it.key()] = it.value().dump();
         }
       }
     }
