@@ -21,15 +21,12 @@
 #include <cerrno>
 #include <chrono>
 #include <clocale>
-#include <condition_variable>
 #include <csignal>
 #include <cstdlib>
 #include <cstring>
-#include <deque>
 #include <exception>
-#include <forward_list>
-#include <future>
 #include <thread>
+#include "bbdo/common.pb.h"
 
 #include <absl/synchronization/mutex.h>
 
@@ -39,6 +36,7 @@
 #include <boost/asio.hpp>
 
 namespace asio = boost::asio;
+using namespace com::centreon;
 
 // with this define boost::interprocess doesn't need Boost.DataTime
 #define BOOST_DATE_TIME_NO_LIB 1
@@ -56,17 +54,26 @@ namespace asio = boost::asio;
 #include "com/centreon/broker/config/state.hh"
 #include "com/centreon/broker/misc/diagnostic.hh"
 #include "com/centreon/common/pool.hh"
+#include "common/crypto/aes256.hh"
 
 #include "com/centreon/exceptions/msg_fmt.hh"
 #include "common/log_v2/log_v2.hh"
 
+using log_v2 = common::log_v2::log_v2;
+
 using namespace com::centreon::broker;
 using namespace com::centreon::exceptions;
 
 std::shared_ptr<asio::io_context> g_io_context =
     std::make_shared<asio::io_context>();
 
-using log_v2 = com::centreon::common::log_v2::log_v2;
+std::shared_ptr<boost::asio::signal_set> signals =
+    std::make_shared<boost::asio::signal_set>(*g_io_context, SIGHUP, SIGTERM);
+
+std::shared_ptr<com::centreon::common::crypto::aes256> credentials_decrypt;
+
+constexpr std::string_view _engine_context_path =
+    "/etc/centreon-engine/engine-context.json";
 
 // Main config file.
 static std::vector<std::string> gl_mainconfigfiles;
@@ -81,71 +88,105 @@ static struct option long_options[] = {{"pool_size", required_argument, 0, 's'},
                                        {0, 0, 0, 0}};
 
 /**
- *  Function called when updating configuration (when program receives
- *  SIGHUP).
+ * @brief reload /etc/centreon-engine/engine-context.json
  *
- *  @param[in] signum Signal number.
+ * @param core_logger
  */
-static void hup_handler(int) {
-  // Disable SIGHUP handling during handler execution.
-  signal(SIGHUP, SIG_IGN);
-
-  // Log message.
-  auto core_logger = log_v2::instance().get(log_v2::CORE);
-  core_logger->info("main: configuration update requested");
-
+static void reload_engine_context(
+    const std::shared_ptr<spdlog::logger>& core_logger) {
   try {
-    // Parse configuration file.
-    config::parser parsr;
-    config::state conf{parsr.parse(gl_mainconfigfiles.front(), false)};
-    auto& log_conf = conf.mut_log_conf();
-    log_conf.allow_only_atomic_changes(true);
-    try {
-      log_v2::instance().apply(log_conf);
-      /* We update the logger, since the conf has been applied */
-    } catch (const std::exception& e) {
-      core_logger->error("problem while reloading cbd: {}", e.what());
-      core_logger->error("problem while reloading cbd: {}", e.what());
-    }
-
-    try {
-      // Apply resulting configuration.
-      config::applier::state::instance().apply(conf);
-
-      gl_state = conf;
-    } catch (const std::exception& e) {
-      core_logger->error(
-          "main: configuration update could not succeed, reloading previous "
-          "configuration: {}",
-          e.what());
-      config::applier::state::instance().apply(gl_state);
-    } catch (...) {
-      core_logger->error(
-          "main: configuration update could not succeed, reloading previous "
-          "configuration");
-      config::applier::state::instance().apply(gl_state);
+    if (std::filesystem::is_regular_file(_engine_context_path) &&
+        std::filesystem::file_size(_engine_context_path) > 0) {
+      std::unique_ptr<com::centreon::common::crypto::aes256> new_file =
+          std::make_unique<com::centreon::common::crypto::aes256>(
+              _engine_context_path);
+      // we test validity of keys
+      std::string encrypted = new_file->encrypt("test encrypt");
+      if (new_file->decrypt(encrypted) == "test encrypt") {
+        credentials_decrypt = std::move(new_file);
+      } else {
+        throw std::invalid_argument(
+            "this keys are unable to crypt and decrypt a sentence");
+      }
     }
   } catch (const std::exception& e) {
-    core_logger->info("main: configuration update failed: {}", e.what());
-  } catch (...) {
-    core_logger->info("main: configuration update failed: unknown exception");
+    SPDLOG_LOGGER_ERROR(core_logger, "We can not read {}: {}",
+                        _engine_context_path, e.what());
   }
-
-  // Reenable SIGHUP handler.
-  signal(SIGHUP, hup_handler);
 }
 
 /**
- *  Function called on termination request (when program receives
- *  SIGTERM).
+ * @brief handle signals SIGHUP and SIGTERM
  *
- *  @param[in] signum Unused.
- *  @param[in] info   Signal informations.
- *  @param[in] data   Unused.
+ * @param err
+ * @param signal_number
  */
-static void term_handler(int signum) {
-  (void)signum;
-  gl_term = true;
+static void signal_handler(const std::shared_ptr<spdlog::logger>& core_logger,
+                           const boost::system::error_code& err,
+                           int signal_number) {
+  if (signal_number == SIGTERM) {
+    SPDLOG_LOGGER_INFO(core_logger, "main: SIGTERM received by process {}",
+                       getpid());
+    gl_term = true;
+    return;  // no restart a signals->async_wait
+  } else if (signal_number == SIGHUP) {
+    // Log message.
+    SPDLOG_LOGGER_INFO(core_logger, "main: configuration update requested");
+
+    try {
+      // Parse configuration file.
+      config::parser parsr;
+      config::state conf{parsr.parse(gl_mainconfigfiles.front())};
+      auto& log_conf = conf.mut_log_conf();
+      log_conf.allow_only_atomic_changes(true);
+      try {
+        log_v2::instance().apply(log_conf);
+        /* We update the logger, since the conf has been applied */
+      } catch (const std::exception& e) {
+        SPDLOG_LOGGER_ERROR(core_logger, "problem while reloading cbd: {}",
+                            e.what());
+        SPDLOG_LOGGER_ERROR(core_logger, "problem while reloading cbd: {}",
+                            e.what());
+      }
+
+      reload_engine_context(core_logger);
+
+      try {
+        // Apply resulting configuration.
+        config::applier::state::instance().apply(conf);
+
+        gl_state = conf;
+      } catch (const std::exception& e) {
+        SPDLOG_LOGGER_ERROR(
+            core_logger,
+            "main: configuration update could not succeed, reloading previous "
+            "configuration: {}",
+            e.what());
+        config::applier::state::instance().apply(gl_state);
+      } catch (...) {
+        SPDLOG_LOGGER_ERROR(
+            core_logger,
+            "main: configuration update could not succeed, reloading previous "
+            "configuration");
+        config::applier::state::instance().apply(gl_state);
+      }
+    } catch (const std::exception& e) {
+      SPDLOG_LOGGER_INFO(core_logger, "main: configuration update failed: {}",
+                         e.what());
+    } catch (...) {
+      SPDLOG_LOGGER_INFO(
+          core_logger, "main: configuration update failed: unknown exception");
+    }
+  } else {
+    SPDLOG_LOGGER_ERROR(core_logger,
+                        "main: unimplemented signal handler for signal: {}",
+                        signal_number);
+  }
+  signals->async_wait(
+      [save_signalset = signals, core_logger](
+          const boost::system::error_code& err, int signal_number) {
+        signal_handler(core_logger, err, signal_number);
+      });
 }
 
 /**
@@ -172,21 +213,12 @@ int main(int argc, char* argv[]) {
   auto core_logger = log_v2::instance().get(log_v2::CORE);
   com::centreon::common::pool::load(g_io_context, core_logger);
 
-  // Set configuration update handler.
-  if (signal(SIGHUP, hup_handler) == SIG_ERR) {
-    char const* err{strerror(errno)};
-    core_logger->info(
-        "main: could not register configuration update handler: {}", err);
-  }
-
-  // Init signal handler.
-  struct sigaction sigterm_act;
-  memset(&sigterm_act, 0, sizeof(sigterm_act));
-  sigterm_act.sa_handler = &term_handler;
-
-  // Set termination handler.
-  if (sigaction(SIGTERM, &sigterm_act, nullptr) < 0)
-    core_logger->info("main: could not register termination handler");
+  // Set signal handler.
+  signals->async_wait(
+      [save_signalset = signals, core_logger](
+          const boost::system::error_code& err, int signal_number) {
+        signal_handler(core_logger, err, signal_number);
+      });
 
   // Return value.
   int retval(0);
@@ -231,39 +263,49 @@ int main(int argc, char* argv[]) {
     // Check parameters requirements.
     if (diagnose) {
       if (gl_mainconfigfiles.empty()) {
-        core_logger->error(
+        SPDLOG_LOGGER_ERROR(
+            core_logger,
             "diagnostic: no configuration file provided: DIAGNOSTIC FILE MIGHT "
             "NOT BE USEFUL");
       }
       misc::diagnostic diag;
       diag.generate(gl_mainconfigfiles);
     } else if (help) {
-      core_logger->info(
+      SPDLOG_LOGGER_INFO(
+          core_logger,
           "USAGE: {} [-s <poolsize>] [-c] [-D] [-h] [-v] [<configfile>]",
           argv[0]);
 
-      core_logger->info("  '-s<poolsize>'  Set poolsize threads.");
-      core_logger->info("  '-c'  Check configuration file.");
-      core_logger->info("  '-D'  Generate a diagnostic file.");
-      core_logger->info("  '-h'  Print this help.");
-      core_logger->info("  '-v'  Print Centreon Broker version.");
-      core_logger->info("Centreon Broker " CENTREON_BROKER_VERSION);
-      core_logger->info("Copyright 2009-" CENTREON_CURRENT_YEAR " Centreon");
-      core_logger->info(
+      SPDLOG_LOGGER_INFO(core_logger,
+                         "  '-s<poolsize>'  Set poolsize threads.");
+      SPDLOG_LOGGER_INFO(core_logger, "  '-c'  Check configuration file.");
+      SPDLOG_LOGGER_INFO(core_logger, "  '-D'  Generate a diagnostic file.");
+      SPDLOG_LOGGER_INFO(core_logger, "  '-h'  Print this help.");
+      SPDLOG_LOGGER_INFO(core_logger, "  '-v'  Print Centreon Broker version.");
+      SPDLOG_LOGGER_INFO(core_logger,
+                         "Centreon Broker " CENTREON_BROKER_VERSION);
+      SPDLOG_LOGGER_INFO(core_logger,
+                         "Copyright 2009-" CENTREON_CURRENT_YEAR " Centreon");
+      SPDLOG_LOGGER_INFO(
+          core_logger,
           "License ASL 2.0 <http://www.apache.org/licenses/LICENSE-2.0>");
       retval = 0;
     } else if (version) {
-      core_logger->info("Centreon Broker {}", CENTREON_BROKER_VERSION);
+      SPDLOG_LOGGER_INFO(core_logger, "Centreon Broker {}",
+                         CENTREON_BROKER_VERSION);
       retval = 0;
     } else if (gl_mainconfigfiles.empty()) {
-      core_logger->error(
+      SPDLOG_LOGGER_ERROR(
+          core_logger,
           "USAGE: {} [-s <poolsize>] [-c] [-D] [-h] [-v] [<configfile>]\n\n",
           argv[0]);
       return 1;
     } else {
-      core_logger->info("Centreon Broker {}", CENTREON_BROKER_VERSION);
-      core_logger->info("Copyright 2009-2021 Centreon");
-      core_logger->info(
+      SPDLOG_LOGGER_INFO(core_logger, "Centreon Broker {}",
+                         CENTREON_BROKER_VERSION);
+      SPDLOG_LOGGER_INFO(core_logger, "Copyright 2009-2021 Centreon");
+      SPDLOG_LOGGER_INFO(
+          core_logger,
           "License ASL 2.0 <http://www.apache.org/licenses/LICENSE-2.0>");
 
       // Reset locale.
@@ -272,21 +314,24 @@ int main(int argc, char* argv[]) {
       {
         // Parse configuration file.
         config::parser parsr;
-        config::state conf{parsr.parse(gl_mainconfigfiles.front(), false)};
+        config::state conf{parsr.parse(gl_mainconfigfiles.front())};
         auto& log_conf = conf.log_conf();
         /* It is important to apply the log conf before broker threads start.
          * Otherwise we will have issues with concurrent accesses. */
         try {
           log_v2::instance().apply(log_conf);
         } catch (const std::exception& e) {
-          core_logger->error("{}", e.what());
+          SPDLOG_LOGGER_ERROR(core_logger, "{}", e.what());
         }
 
-        core_logger->info("main: process {} pid:{} begin", argv[0], getpid());
+        SPDLOG_LOGGER_INFO(core_logger, "main: process {} pid:{} begin",
+                           argv[0], getpid());
+
+        reload_engine_context(core_logger);
 
         if (n_thread > 0 && n_thread < 100)
           conf.pool_size(n_thread);
-        config::applier::init(conf);
+        config::applier::init(common::BROKER, conf);
 
         // Apply resulting configuration totally or partially.
         config::applier::state::instance().apply(conf, !check);
@@ -314,8 +359,9 @@ int main(int argc, char* argv[]) {
         while (!gl_term) {
           std::this_thread::sleep_for(std::chrono::seconds(1));
         }
-        core_logger->info("main: termination request received by process {}",
-                          getpid());
+        SPDLOG_LOGGER_INFO(core_logger,
+                           "main: termination request received by process {}",
+                           getpid());
       }
       //  Unload endpoints.
       config::applier::deinit();
@@ -324,19 +370,18 @@ int main(int argc, char* argv[]) {
   }
   // Standard exception.
   catch (const std::exception& e) {
-    core_logger->error("Error during cbd exit: {}", e.what());
+    SPDLOG_LOGGER_ERROR(core_logger, "Error during cbd exit: {}", e.what());
     retval = EXIT_FAILURE;
   }
   // Unknown exception.
   catch (...) {
-    core_logger->error("Error general during cbd exit");
+    SPDLOG_LOGGER_ERROR(core_logger, "Error general during cbd exit");
     retval = EXIT_FAILURE;
   }
 
-  core_logger->info("main: process {} pid:{} end exit_code:{}", argv[0],
-                    getpid(), retval);
+  SPDLOG_LOGGER_INFO(core_logger, "main: process {} pid:{} end exit_code:{}",
+                     argv[0], getpid(), retval);
   g_io_context->stop();
-  com::centreon::common::pool::unload();
   log_v2::unload();
   return retval;
 }
