@@ -17,6 +17,7 @@
  */
 
 #include "com/centreon/broker/misc/variant.hh"
+#include <fmt/format.h>
 #include <cassert>
 
 using namespace com::centreon::broker::misc;
@@ -31,6 +32,12 @@ variant::variant() : _type{type_none} {}
  */
 variant::variant(char const* value) : _type{type_string}, _str_value{value} {}
 
+/**
+ *  Constructor
+ */
+variant::variant(const std::string_view& value)
+    : _type{type_string}, _str_value{value} {}
+
 /**
  *  Constructor
  */
