@@ -19,7 +19,6 @@
 
 #include "com/centreon/broker/http_tsdb/factory.hh"
 
-#include "com/centreon/broker/config/parser.hh"
 #include "com/centreon/broker/http_tsdb/column.hh"
 #include "com/centreon/exceptions/msg_fmt.hh"
 
@@ -42,7 +41,7 @@ factory::factory(const std::string& name,
  */
 std::string factory::find_param(config::endpoint const& cfg,
                                 std::string const& key) const {
-  std::map<std::string, std::string>::const_iterator it{cfg.params.find(key)};
+  auto it = cfg.params.find(key);
   if (cfg.params.end() == it)
     throw msg_fmt("{}: no '{}' defined for endpoint '{}'", _name, key,
                   cfg.name);
@@ -56,21 +55,15 @@ std::string factory::find_param(config::endpoint const& cfg,
  *
  *  @return True if the configuration matches the storage layer.
  */
-bool factory::has_endpoint(const config::endpoint& cfg,
-                           io::extension* ext) const {
+bool factory::has_endpoint(config::endpoint& cfg, io::extension* ext) {
+  bool is_ifdb{absl::EqualsIgnoreCase(cfg.type, _name)};
   if (ext)
     *ext = io::extension(boost::algorithm::to_upper_copy(_name), false, false);
-  return absl::EqualsIgnoreCase(cfg.type, _name);
-}
-
-/**
- * @brief Set the default values to the endpoint config read from cfg files
- *
- * @param cfg config to update
- */
-void factory::set_default_values(config::endpoint& cfg) const {
-  cfg.params["cache"] = "yes";
-  cfg.cache_enabled = true;
+  if (is_ifdb) {
+    cfg.params["cache"] = "yes";
+    cfg.cache_enabled = true;
+  }
+  return is_ifdb;
 }
 
 /**
@@ -149,8 +142,7 @@ void factory::create_conf(const config::endpoint& cfg,
   std::string addr(find_param(cfg, "db_host"));
 
   std::string target = "/write";
-  std::map<std::string, std::string>::const_iterator it{
-      cfg.params.find("http_target")};
+  auto it = cfg.params.find("http_target");
   if (it != cfg.params.end()) {
     target = it->second;
   }
