@@ -19,7 +19,6 @@
 #include "com/centreon/broker/lua/broker_utils.hh"
 
 #include <fmt/format.h>
-#include <lua.h>
 #include <sys/stat.h>
 #include "absl/strings/str_split.h"
 #include "absl/strings/string_view.h"
@@ -790,7 +789,7 @@ static int l_broker_base64_encode(lua_State* L) {
   char const* str = lua_tolstring(L, -1, &len);
   std::string_view sv(str, len);
 
-  std::string retval = base64_encode(sv);
+  std::string retval = com::centreon::common::crypto::base64_encode(sv);
 
   lua_pushlstring(L, retval.c_str(), retval.size());
   return 1;
