@@ -18,38 +18,28 @@
  */
 #include <gtest/gtest.h>
 #include <com/centreon/broker/stats/parser.hh>
-#include <com/centreon/broker/stats/worker.hh>
 #include <com/centreon/broker/stats/worker_pool.hh>
-#include <nlohmann/json.hpp>
 #include "com/centreon/broker/config/applier/endpoint.hh"
 #include "com/centreon/broker/config/applier/state.hh"
 #include "com/centreon/broker/config/parser.hh"
 #include "com/centreon/broker/exceptions/shutdown.hh"
 #include "com/centreon/broker/file/disk_accessor.hh"
 #include "com/centreon/broker/io/events.hh"
-#include "com/centreon/broker/io/factory.hh"
 #include "com/centreon/broker/io/protocols.hh"
 #include "com/centreon/broker/io/stream.hh"
 #include "com/centreon/broker/misc/misc.hh"
-#include "com/centreon/broker/misc/string.hh"
 #include "com/centreon/broker/multiplexing/engine.hh"
-#include "com/centreon/broker/multiplexing/muxer_filter.hh"
 #include "com/centreon/broker/sql/mysql_manager.hh"
 #include "com/centreon/broker/stats/builder.hh"
-#include "com/centreon/broker/stats/center.hh"
-#include "com/centreon/common/pool.hh"
-#include "com/centreon/exceptions/msg_fmt.hh"
 
 using namespace com::centreon::exceptions;
 using namespace com::centreon::broker;
 
-
 class StatsTest : public ::testing::Test {
  public:
   void SetUp() override {
-    stats::center::load();
+    config::applier::state::load(com::centreon::common::BROKER);
     mysql_manager::load();
-    config::applier::state::load();
     file::disk_accessor::load(10000);
     multiplexing::engine::load();
     io::protocols::load();
@@ -66,7 +56,6 @@ class StatsTest : public ::testing::Test {
     io::protocols::unload();
     mysql_manager::unload();
     file::disk_accessor::unload();
-    stats::center::unload();
   }
 };
 
@@ -86,33 +75,6 @@ TEST_F(StatsTest, Builder) {
   ASSERT_TRUE(result["mysql manager"]["delay since last check"].is_string());
 }
 
-// TEST_F(StatsTest, BuilderWithModules) {
-//   stats::builder build;
-//   auto& modules = config::applier::state::instance().get_modules();
-//   modules.apply({"storage/20-storage.so", "lib/10-neb.so", "lua/70-lua.so"},
-//                 ".", nullptr);
-//
-//   build.build();
-//
-//   nlohmann::json result;
-//   ASSERT_NO_THROW(result = nlohmann::json::parse(build.data()));
-//
-//   ASSERT_TRUE(result.is_object());
-//   ASSERT_EQ(result["version"], CENTREON_BROKER_VERSION);
-//   ASSERT_EQ(result["pid"], getpid());
-//   ASSERT_TRUE(result["now"].is_string());
-//   ASSERT_TRUE(result["asio_version"].is_string());
-//   ASSERT_TRUE(result["mysql manager"].is_object());
-//   ASSERT_TRUE(result["mysql manager"]["delay since last check"].is_string());
-//
-//   ASSERT_EQ(result["module./lib/10-neb.so"]["state"].get<std::string>(),
-//             "loaded");
-//   ASSERT_EQ(result["module./storage/20-storage.so"]["state"].get<std::string>(),
-//             "loaded");
-//   ASSERT_EQ(result["module./lua/70-lua.so"]["state"].get<std::string>(),
-//             "loaded");
-// }
-
 class st : public io::stream {
  public:
   st() : io::stream("st") {}
@@ -151,18 +113,19 @@ class fact : public io::factory {
  public:
   fact() {}
 
-  bool has_endpoint(const config::endpoint& cfg __attribute__((__unused__)),
-                    io::extension* ext) const override {
+  bool has_endpoint(config::endpoint& cfg __attribute__((__unused__)),
+                    io::extension* ext) override {
     if (ext)
       *ext = io::extension("FACT", false, false);
     return true;
   }
 
   io::endpoint* new_endpoint(
-      config::endpoint& cfg __attribute__((__unused__)),
+      config::endpoint& cfg [[maybe_unused]],
+      const std::map<std::string, std::string>& global_params [[maybe_unused]],
       bool& is_acceptor,
-      __attribute__((__unused__)) std::shared_ptr<persistent_cache> cache =
-          std::shared_ptr<persistent_cache>()) const override {
+      std::shared_ptr<persistent_cache> cache
+      [[maybe_unused]] = std::shared_ptr<persistent_cache>()) const override {
     endp* p{new endp()};
     is_acceptor = true;
     return p;
@@ -242,7 +205,7 @@ TEST_F(StatsTest, BuilderWithEndpoints) {
   // Parse.
   config::parser p;
   config::state s;
-  ASSERT_NO_THROW(s = p.parse(config_file, false));
+  ASSERT_NO_THROW(s = p.parse(config_file));
 
   auto test = std::make_shared<fact>();
   io::protocols::instance().reg("CentreonInput", test, 1, 7);
@@ -250,7 +213,7 @@ TEST_F(StatsTest, BuilderWithEndpoints) {
   io::protocols::instance().reg("CentreonRetention", test, 1, 7);
   io::protocols::instance().reg("CentreonSecondaryFailover1", test, 1, 7);
   io::protocols::instance().reg("CentreonSecondaryFailover2", test, 1, 7);
-  config::applier::endpoint::instance().apply(s.endpoints());
+  config::applier::endpoint::instance().apply(s.endpoints(), {});
 
   // Remove temporary file.
   ::remove(config_file.c_str());
