@@ -17,6 +17,7 @@
  */
 
 #include <fmt/format.h>
+#include <fmt/ranges.h>
 
 #include <cfloat>
 
@@ -27,6 +28,7 @@
 #include "bbdo/storage/status.hh"
 #include "com/centreon/broker/misc/misc.hh"
 #include "com/centreon/broker/misc/string.hh"
+#include "com/centreon/broker/multiplexing/publisher.hh"
 #include "com/centreon/broker/neb/events.hh"
 #include "com/centreon/broker/sql/table_max_size.hh"
 #include "com/centreon/broker/storage/conflict_manager.hh"
