@@ -90,7 +90,7 @@ using namespace com::centreon::common;
  * @param logger
  * @param exe_path exe without arguments
  * @param use_setpgid if true, we set process group of child process
- * @param use_stdin if true, we open a stdin pipe to child process, if false,
+ * @param use_stdin if true, we open a stding pipe to child process, if false,
  * we open a stdin pipe, but we close it as soon as child process is created. By
  * doing this, child process will read an eof.
  * @param args command arguments
@@ -496,14 +496,15 @@ void process<use_mutex>::_on_stdout_read(const boost::system::error_code& err,
                             "pid:{} end read from stdout of process {}: {}",
                             _proc->proc.handle().id(), *_args, err.message());
       } else {
-        SPDLOG_LOGGER_ERROR(_logger,
-                            "fail read from stdout of process {}: {} {}",
-                            *_args, err.value(), err.message());
+        SPDLOG_LOGGER_ERROR(
+            _logger, "pid:{} fail read from stdout of process {}: {} {}",
+            _proc->proc.handle().id(), *_args, err.value(), err.message());
       }
       _completion_flags.fetch_or(e_completion_flags::stdout_eof);
       eof = true;
     } else {
-      SPDLOG_LOGGER_TRACE(_logger, " process: {} read from stdout: {}", *_args,
+      SPDLOG_LOGGER_TRACE(_logger, "pid:{} process: {} read from stdout: {}",
+                          _proc->proc.handle().id(), *_args,
                           std::string_view(_stdout_read_buffer, nb_read));
       if (!_stdout_handler) {
         _stdout.append(_stdout_read_buffer, nb_read);
@@ -566,14 +567,15 @@ void process<use_mutex>::_on_stderr_read(const boost::system::error_code& err,
                             "pid:{} end read from stderr of process {}: {}",
                             _proc->proc.handle().id(), *_args, err.message());
       } else {
-        SPDLOG_LOGGER_ERROR(_logger,
-                            "fail read from stderr of process {}: {} {}",
-                            *_args, err.value(), err.message());
+        SPDLOG_LOGGER_ERROR(
+            _logger, "pid:{} fail read from stderr of process {}: {} {}",
+            _proc->proc.handle().id(), *_args, err.value(), err.message());
       }
       _completion_flags.fetch_or(e_completion_flags::stderr_eof);
       eof = true;
     } else {
-      SPDLOG_LOGGER_TRACE(_logger, " process: {} read from stdout: {}", *_args,
+      SPDLOG_LOGGER_TRACE(_logger, "pid:{} process: {} read from stdout: {}",
+                          *_args, _proc->proc.handle().id(),
                           std::string_view(_stderr_read_buffer, nb_read));
       if (!_stderr_handler) {
         _stderr.append(_stderr_read_buffer, nb_read);
@@ -639,12 +641,14 @@ template <bool use_mutex>
 void process<use_mutex>::kill() {
   detail::lock<use_mutex> l(&_protect);
   if (_proc) {
-    SPDLOG_LOGGER_INFO(_logger, "kill process {}", *_args);
+    auto child_pid = _proc->proc.handle().id();
+    SPDLOG_LOGGER_INFO(_logger, "pid:{} kill process {}", child_pid, *_args);
     boost::system::error_code err;
     _proc->proc.terminate(err);
     _terminated = true;
     if (err) {
-      SPDLOG_LOGGER_INFO(_logger, "fail to kill {}: {}", *_args, err.message());
+      SPDLOG_LOGGER_INFO(_logger, "pid:{} fail to kill {}: {}", child_pid,
+                         *_args, err.message());
     }
   }
 }
@@ -655,4 +659,4 @@ template class process<true>;
 
 template class process<false>;
 
-}  // namespace com::centreon::common
\ No newline at end of file
+}  // namespace com::centreon::common
