@@ -36,7 +36,7 @@ using namespace com::centreon;
 using namespace com::centreon::engine::logging;
 using namespace com::centreon::engine::checks;
 
-std::shared_ptr<checker> checker::_instance;
+checker* checker::_instance = nullptr;
 static constexpr time_t max_check_reaper_time = 30;
 
 /**
@@ -53,11 +53,14 @@ checker& checker::instance() {
 
 void checker::init(bool used_by_test) {
   if (!_instance)
-    _instance = std::make_shared<checker>(used_by_test);
+    _instance = new checker(used_by_test);
 }
 
 void checker::deinit() {
-  _instance.reset();
+  if (_instance) {
+    delete _instance;
+    _instance = nullptr;
+  }
 }
 
 void checker::clear() noexcept {
@@ -308,7 +311,7 @@ void checker::run_sync(host* hst,
 
   // Send broker event.
   broker_host_check(NEBTYPE_HOSTCHECK_INITIATE, hst, checkable::check_active,
-                    nullptr, nullptr);
+                    nullptr);
 
   // Execute command synchronously.
   host::host_state host_result(_execute_sync(hst));
@@ -325,6 +328,10 @@ void checker::run_sync(host* hst,
       << "* Sync host check done: new state=" << hst->get_current_state();
   SPDLOG_LOGGER_DEBUG(checks_logger, "* Sync host check done: new state={}",
                       static_cast<uint32_t>(hst->get_current_state()));
+
+  // Send event broker.
+  broker_host_check(NEBTYPE_HOSTCHECK_PROCESSED, hst, checkable::check_active,
+                    nullptr);
 }
 
 /**************************************
@@ -337,18 +344,13 @@ void checker::run_sync(host* hst,
  *  Default constructor.
  */
 checker::checker(bool used_by_test)
-    : commands::command_listener(), _used_by_test(used_by_test) {
-  SPDLOG_LOGGER_DEBUG(commands_logger, "create checker {:p}",
-                      static_cast<const void*>(this));
-}
+    : commands::command_listener(), _used_by_test(used_by_test) {}
 
 /**
  *  Default destructor.
  */
-checker::~checker() {
+checker::~checker() noexcept {
   clear();
-  SPDLOG_LOGGER_DEBUG(commands_logger, "delete checker {:p}",
-                      static_cast<const void*>(this));
 }
 
 /**
@@ -445,6 +447,12 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
   // Send broker event.
   timeval start_time{0, 0};
   timeval end_time{0, 0};
+  int ret(broker_host_check(NEBTYPE_HOSTCHECK_SYNC_PRECHECK, hst,
+                            checkable::check_active, nullptr));
+
+  // Host sync check was cancelled or overriden by NEB module.
+  if ((NEBERROR_CALLBACKCANCEL == ret) || (NEBERROR_CALLBACKOVERRIDE == ret))
+    return hst->get_current_state();
 
   // Get current host macros.
   nagios_macros* macros(get_global_macros());
@@ -462,6 +470,11 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
   // Get command object.
   commands::command::pointer cmd = hst->get_check_command_ptr();
   std::string processed_cmd(cmd->process_cmd(macros));
+  const char* tmp_processed_cmd = processed_cmd.c_str();
+
+  // Send broker event.
+  broker_host_check(NEBTYPE_HOSTCHECK_RAW_START, hst, checkable::check_active,
+                    processed_cmd.c_str());
 
   // Debug messages.
   engine_logger(dbg_commands, more)
@@ -480,6 +493,11 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
   hst->set_long_plugin_output("");
   hst->set_perf_data("");
 
+  // Send broker event.
+  timeval start_cmd;
+  timeval end_cmd{0, 0};
+  gettimeofday(&start_cmd, nullptr);
+
   commands::result res;
 
   auto run_failure = [&](const std::string& reason) {
@@ -506,11 +524,7 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
   } else {
     // Run command.
     try {
-#ifdef LEGACY_CONF
-      cmd->run(processed_cmd, *macros, config->host_check_timeout(), res);
-#else
       cmd->run(processed_cmd, *macros, pb_config.host_check_timeout(), res);
-#endif
     } catch (std::exception const& e) {
       run_failure("(Execute command failed)");
 
@@ -527,15 +541,20 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
   if (res.end_time >= res.start_time)
     execution_time = res.end_time.to_seconds() - res.start_time.to_seconds();
 
+  // Send broker event.
+  memset(&start_cmd, 0, sizeof(start_time));
+  start_cmd.tv_sec = res.start_time.to_seconds();
+  start_cmd.tv_usec =
+      res.start_time.to_useconds() - start_cmd.tv_sec * 1000000ull;
+  memset(&end_cmd, 0, sizeof(end_time));
+  end_cmd.tv_sec = res.end_time.to_seconds();
+  end_cmd.tv_usec = res.end_time.to_useconds() - end_cmd.tv_sec * 1000000ull;
+
   // Cleanup.
   clear_volatile_macros_r(macros);
 
   // If the command timed out.
-#ifdef LEGACY_CONF
-  uint32_t host_check_timeout = config->host_check_timeout();
-#else
   uint32_t host_check_timeout = pb_config.host_check_timeout();
-#endif
   if (res.exit_status == common::e_exit_status::timeout) {
     res.output = fmt::format("Host check timed out after {}  seconds",
                              host_check_timeout);
@@ -560,8 +579,8 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
   std::string perfdata_output;
 
   // Parse the output: short and long output, and perf data.
-  common::parse_check_output(res.output, pl_output, lpl_output, perfdata_output,
-                             true, false);
+  parse_check_output(res.output, pl_output, lpl_output, perfdata_output, true,
+                     false);
 
   hst->set_plugin_output(pl_output);
   hst->set_long_plugin_output(lpl_output);
@@ -592,6 +611,10 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
   // Get the end time of command.
   gettimeofday(&end_time, nullptr);
 
+  // Send broker event.
+  broker_host_check(NEBTYPE_HOSTCHECK_RAW_END, hst, checkable::check_active,
+                    tmp_processed_cmd);
+
   // Termination.
   engine_logger(dbg_checks, basic)
       << "** Sync host check done: state=" << return_result;
