@@ -39,17 +39,13 @@ constexpr std::string_view _query_ending("\0\0\0\0", 4);
 connector::connector(const std::string& connector_name,
                      const std::string& connector_line,
                      const std::shared_ptr<asio::io_context>& io_context,
-                     const std::shared_ptr<command_listener>& listener)
+                     command_listener* listener)
     : command(connector_name, connector_line, listener, e_type::connector),
       _state(e_state::not_started),
       _logger(commands_logger),
       _io_context(io_context),
       _timeout_timer(*io_context) {
-#ifdef LEGACY_CONF
-  bool enable_environment_macros = config->enable_environment_macros();
-#else
   bool enable_environment_macros = pb_config.enable_environment_macros();
-#endif
   if (enable_environment_macros) {
     SPDLOG_LOGGER_WARN(runtime_logger,
                        "Warning: Connector does not enable environment macros");
@@ -74,7 +70,7 @@ std::shared_ptr<connector> connector::load(
     std::string const& connector_name,
     std::string const& connector_line,
     const std::shared_ptr<asio::io_context>& io_context,
-    const std::shared_ptr<command_listener>& listener) {
+    command_listener* listener) {
   std::shared_ptr<connector> ret(
       new connector(connector_name, connector_line, io_context, listener));
   ret->_timeout_timer_start();
@@ -94,7 +90,7 @@ uint64_t connector::run(const std::string& processed_cmd,
                         nagios_macros&,
                         uint32_t timeout,
                         const check_result::pointer& to_push_to_checker,
-                        const void* caller) {
+                        const notifier* caller) {
   SPDLOG_LOGGER_TRACE(_logger,
                       "connector::run: connector='{}', cmd='{}', timeout={}",
                       _name, processed_cmd, timeout);
