@@ -23,6 +23,7 @@
 #include "com/centreon/engine/logging/logger.hh"
 #include "com/centreon/engine/macros.hh"
 #include "com/centreon/exceptions/msg_fmt.hh"
+#include "opentelemetry/proto/collector/metrics/v1/metrics_service.pb.h"
 
 using namespace com::centreon::common;
 using namespace com::centreon::engine;
@@ -39,12 +40,10 @@ using namespace com::centreon::engine::commands;
 raw_v2::raw_v2(const std::shared_ptr<asio::io_context> io_context,
                std::string const& name,
                std::string const& command_line,
-               const std::shared_ptr<command_listener>& listener)
+               command_listener* listener)
     : command(name, command_line, listener, e_type::raw),
       _io_context(io_context),
       _commands_logger(commands_logger) {
-  SPDLOG_LOGGER_TRACE(commands_logger, "create raw_v2 {:p}",
-                      static_cast<const void*>(this));
   if (_command_line.empty()) {
     throw exceptions::msg_fmt(
         "Could not create {}'' command: command line is empty", _name);
@@ -56,8 +55,6 @@ raw_v2::raw_v2(const std::shared_ptr<asio::io_context> io_context,
  *
  */
 raw_v2::~raw_v2() {
-  SPDLOG_LOGGER_TRACE(commands_logger, "delete raw_v2 {:p}",
-                      static_cast<const void*>(this));
   for (std::shared_ptr<com::centreon::common::process<true>> to_kill :
        _running) {
     _commands_logger->debug("raw_v2::~raw_v2: killing process for command '{}'",
@@ -205,12 +202,8 @@ static void _build_custom_service_macro_environment(
 static void _build_macrosx_environment(
     nagios_macros& macros,
     boost::process::v2::process_environment& env) {
-#ifdef LEGACY_CONF
-  bool use_large_installation_tweaks = config->use_large_installation_tweaks();
-#else
   bool use_large_installation_tweaks =
       pb_config.use_large_installation_tweaks();
-#endif
   std::string key;
   for (uint32_t i = 0; i < MACRO_X_COUNT; ++i) {
     int release_memory(0);
@@ -249,11 +242,7 @@ static std::vector<std::pair<std::string, std::string>> _empty_args;
  */
 void _build_environment_macros(nagios_macros& macros,
                                boost::process::v2::process_environment& env) {
-#ifdef LEGACY_CONF
-  bool enable_environment_macros = config->enable_environment_macros();
-#else
   bool enable_environment_macros = pb_config.enable_environment_macros();
-#endif
   if (enable_environment_macros) {
     _build_macrosx_environment(macros, env);
     _build_argv_macro_environment(macros, env);
@@ -311,7 +300,7 @@ uint64_t raw_v2::run(const std::string& processed_cmd,
                      nagios_macros& macros,
                      uint32_t timeout,
                      const check_result::pointer& to_push_to_checker,
-                     const void* caller) {
+                     const notifier* caller) {
   engine_logger(dbg_commands, basic)
       << "raw_v2::run: cmd='" << processed_cmd << "', timeout=" << timeout;
   SPDLOG_LOGGER_TRACE(_commands_logger, "raw_v2::run: cmd='{}', timeout={}",
