@@ -242,11 +242,7 @@ bool notifier::_is_notification_viable_normal(reason_type type
   }
 
   /* are notifications enabled? */
-#ifdef LEGACY_CONF
-  bool enable_notifications = config->enable_notifications();
-#else
   bool enable_notifications = pb_config.enable_notifications();
-#endif
   if (!enable_notifications) {
     engine_logger(dbg_notifications, more)
         << "Notifications are disabled, so notifications will "
@@ -358,11 +354,7 @@ bool notifier::_is_notification_viable_normal(reason_type type
     return false;
   }
 
-#ifdef LEGACY_CONF
-  uint32_t interval_length = config->interval_length();
-#else
   uint32_t interval_length = pb_config.interval_length();
-#endif
   if (_first_notification_delay > 0 && !_notification[cat_normal] &&
       get_last_hard_state_change() +
               _first_notification_delay * interval_length >
@@ -437,11 +429,7 @@ bool notifier::_is_notification_viable_recovery(reason_type type
   bool retval{true};
   bool send_later{false};
 
-#ifdef LEGACY_CONF
-  bool enable_notifications = config->enable_notifications();
-#else
   bool enable_notifications = pb_config.enable_notifications();
-#endif
   /* are notifications enabled? */
   if (!enable_notifications) {
     engine_logger(dbg_notifications, more)
@@ -467,15 +455,9 @@ bool notifier::_is_notification_viable_recovery(reason_type type
     std::time_t now;
     std::time(&now);
 
-#ifdef LEGACY_CONF
-    uint32_t interval_length = config->interval_length();
-    bool use_send_recovery_notifications_anyways =
-        config->use_send_recovery_notifications_anyways();
-#else
     uint32_t interval_length = pb_config.interval_length();
     bool use_send_recovery_notifications_anyways =
         pb_config.send_recovery_notifications_anyways();
-#endif
 
     // if use_send_recovery_notifications_anyways flag is set, we don't take
     // timeperiod into account for recovery
@@ -612,11 +594,7 @@ bool notifier::_is_notification_viable_acknowledgement(
     return true;
   }
 
-#ifdef LEGACY_CONF
-  bool enable_notifications = config->enable_notifications();
-#else
   bool enable_notifications = pb_config.enable_notifications();
-#endif
   /* are notifications enabled? */
   if (!enable_notifications) {
     engine_logger(dbg_notifications, more)
@@ -667,11 +645,7 @@ bool notifier::_is_notification_viable_flapping(reason_type type,
   }
 
   /* are notifications enabled? */
-#ifdef LEGACY_CONF
-  bool enable_notifications = config->enable_notifications();
-#else
   bool enable_notifications = pb_config.enable_notifications();
-#endif
   if (!enable_notifications) {
     engine_logger(dbg_notifications, more)
         << "Notifications are disabled, so notifications will "
@@ -783,11 +757,7 @@ bool notifier::_is_notification_viable_downtime(reason_type type
   }
 
   /* are notifications enabled? */
-#ifdef LEGACY_CONF
-  bool enable_notifications = config->enable_notifications();
-#else
   bool enable_notifications = pb_config.enable_notifications();
-#endif
   if (!enable_notifications) {
     engine_logger(dbg_notifications, more)
         << "Notifications are disabled, so notifications will "
@@ -860,11 +830,7 @@ bool notifier::_is_notification_viable_custom(reason_type type
   }
 
   /* are notifications enabled? */
-#ifdef LEGACY_CONF
-  bool enable_notifications = config->enable_notifications();
-#else
   bool enable_notifications = pb_config.enable_notifications();
-#endif
   if (!enable_notifications) {
     engine_logger(dbg_notifications, more)
         << "Notifications are disabled, so notifications will "
@@ -1684,11 +1650,7 @@ time_t notifier::get_next_notification_time(time_t offset) {
                      interval_to_use);
 
   /* calculate next notification time */
-#ifdef LEGACY_CONF
-  uint32_t interval_length = config->interval_length();
-#else
   uint32_t interval_length = pb_config.interval_length();
-#endif
   time_t next_notification{
       offset + static_cast<time_t>(interval_to_use * interval_length)};
 
