@@ -1,21 +1,21 @@
 /**
-* Copyright 2011-2013 Merethis
-*
-* This file is part of Centreon Engine.
-*
-* Centreon Engine is free software: you can redistribute it and/or
-* modify it under the terms of the GNU General Public License version 2
-* as published by the Free Software Foundation.
-*
-* Centreon Engine is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-* General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with Centreon Engine. If not, see
-* <http://www.gnu.org/licenses/>.
-*/
+ * Copyright 2011-2013 Merethis
+ *
+ * This file is part of Centreon Engine.
+ *
+ * Centreon Engine is free software: you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License version 2
+ * as published by the Free Software Foundation.
+ *
+ * Centreon Engine is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with Centreon Engine. If not, see
+ * <http://www.gnu.org/licenses/>.
+ */
 
 #include "com/centreon/engine/downtimes/downtime.hh"
 #include "com/centreon/engine/retention/downtime.hh"
@@ -28,16 +28,16 @@ using namespace com::centreon::engine;
                              &retention::downtime::method>::generic
 
 retention::downtime::setters const retention::downtime::_setters[] = {
-    {"author", SETTER(std::string const&, _set_author)},
-    {"comment", SETTER(std::string const&, _set_comment_data)},
+    {"author", SETTER(const std::string&, _set_author)},
+    {"comment", SETTER(const std::string&, _set_comment_data)},
     {"downtime_id", SETTER(unsigned long, _set_downtime_id)},
     {"duration", SETTER(unsigned long, _set_duration)},
     {"end_time", SETTER(time_t, _set_end_time)},
     {"entry_time", SETTER(time_t, _set_entry_time)},
     {"fixed", SETTER(bool, _set_fixed)},
-    {"host_name", SETTER(std::string const&, _set_host_name)},
+    {"host_name", SETTER(const std::string&, _set_host_name)},
     {"service_description",
-     SETTER(std::string const&, _set_service_description)},
+     SETTER(const std::string&, _set_service_description)},
     {"start_time", SETTER(time_t, _set_start_time)},
     {"triggered_by", SETTER(unsigned long, _set_triggered_by)}};
 
@@ -69,7 +69,7 @@ retention::downtime::downtime(downtime const& right) : object(right) {
 /**
  *  Destructor.
  */
-retention::downtime::~downtime() throw() {}
+retention::downtime::~downtime() noexcept {}
 
 /**
  *  Copy operator.
@@ -94,7 +94,7 @@ retention::downtime& retention::downtime::operator=(downtime const& right) {
     _start_time = right._start_time;
     _triggered_by = right._triggered_by;
   }
-  return (*this);
+  return *this;
 }
 
 /**
@@ -104,16 +104,17 @@ retention::downtime& retention::downtime::operator=(downtime const& right) {
  *
  *  @return True if is the same object, otherwise false.
  */
-bool retention::downtime::operator==(downtime const& right) const throw() {
-  return (
-      object::operator==(right) && _author == right._author &&
-      _comment_data == right._comment_data &&
-      _downtime_id == right._downtime_id &&
-      _downtime_type == right._downtime_type && _duration == right._duration &&
-      _end_time == right._end_time && _entry_time == right._entry_time &&
-      _fixed == right._fixed && _host_name == right._host_name &&
-      _service_description == right._service_description &&
-      _start_time == right._start_time && _triggered_by == right._triggered_by);
+bool retention::downtime::operator==(downtime const& right) const noexcept {
+  return object::operator==(right) && _author == right._author &&
+         _comment_data == right._comment_data &&
+         _downtime_id == right._downtime_id &&
+         _downtime_type == right._downtime_type &&
+         _duration == right._duration && _end_time == right._end_time &&
+         _entry_time == right._entry_time && _fixed == right._fixed &&
+         _host_name == right._host_name &&
+         _service_description == right._service_description &&
+         _start_time == right._start_time &&
+         _triggered_by == right._triggered_by;
 }
 
 /**
@@ -123,8 +124,8 @@ bool retention::downtime::operator==(downtime const& right) const throw() {
  *
  *  @return True if is not the same object, otherwise false.
  */
-bool retention::downtime::operator!=(downtime const& right) const throw() {
-  return (!operator==(right));
+bool retention::downtime::operator!=(downtime const& right) const noexcept {
+  return !operator==(right);
 }
 
 /**
@@ -138,8 +139,8 @@ bool retention::downtime::operator!=(downtime const& right) const throw() {
 bool retention::downtime::set(char const* key, char const* value) {
   for (unsigned int i(0); i < sizeof(_setters) / sizeof(_setters[0]); ++i)
     if (!strcmp(_setters[i].name, key))
-      return ((_setters[i].func)(*this, value));
-  return (false);
+      return (_setters[i].func)(*this, value);
+  return false;
 }
 
 /**
@@ -147,8 +148,8 @@ bool retention::downtime::set(char const* key, char const* value) {
  *
  * @return The author.
  */
-std::string retention::downtime::author() const throw() {
-  return (_author);
+std::string retention::downtime::author() const noexcept {
+  return _author;
 }
 
 /**
@@ -156,8 +157,8 @@ std::string retention::downtime::author() const throw() {
  *
  * @return The comment_data.
  */
-std::string retention::downtime::comment_data() const throw() {
-  return (_comment_data);
+std::string retention::downtime::comment_data() const noexcept {
+  return _comment_data;
 }
 
 /**
@@ -165,8 +166,8 @@ std::string retention::downtime::comment_data() const throw() {
  *
  * @return The downtime_id.
  */
-unsigned long retention::downtime::downtime_id() const throw() {
-  return (_downtime_id);
+unsigned long retention::downtime::downtime_id() const noexcept {
+  return _downtime_id;
 }
 
 /**
@@ -174,9 +175,9 @@ unsigned long retention::downtime::downtime_id() const throw() {
  *
  * @return The downtime_type.
  */
-retention::downtime::type_id retention::downtime::downtime_type() const
-    throw() {
-  return (_downtime_type);
+retention::downtime::type_id retention::downtime::downtime_type()
+    const noexcept {
+  return _downtime_type;
 }
 
 /**
@@ -184,8 +185,8 @@ retention::downtime::type_id retention::downtime::downtime_type() const
  *
  * @return The duration.
  */
-unsigned long retention::downtime::duration() const throw() {
-  return (_duration);
+unsigned long retention::downtime::duration() const noexcept {
+  return _duration;
 }
 
 /**
@@ -193,8 +194,8 @@ unsigned long retention::downtime::duration() const throw() {
  *
  * @return The end_time.
  */
-time_t retention::downtime::end_time() const throw() {
-  return (_end_time);
+time_t retention::downtime::end_time() const noexcept {
+  return _end_time;
 }
 
 /**
@@ -202,8 +203,8 @@ time_t retention::downtime::end_time() const throw() {
  *
  * @return The entry_time.
  */
-time_t retention::downtime::entry_time() const throw() {
-  return (_entry_time);
+time_t retention::downtime::entry_time() const noexcept {
+  return _entry_time;
 }
 
 /**
@@ -211,8 +212,8 @@ time_t retention::downtime::entry_time() const throw() {
  *
  * @return The fixed.
  */
-bool retention::downtime::fixed() const throw() {
-  return (_fixed);
+bool retention::downtime::fixed() const noexcept {
+  return _fixed;
 }
 
 /**
@@ -220,8 +221,8 @@ bool retention::downtime::fixed() const throw() {
  *
  * @return The host_name.
  */
-std::string retention::downtime::host_name() const throw() {
-  return (_host_name);
+std::string retention::downtime::host_name() const noexcept {
+  return _host_name;
 }
 
 /**
@@ -229,8 +230,8 @@ std::string retention::downtime::host_name() const throw() {
  *
  * @return The service_description.
  */
-std::string retention::downtime::service_description() const throw() {
-  return (_service_description);
+std::string retention::downtime::service_description() const noexcept {
+  return _service_description;
 }
 
 /**
@@ -238,8 +239,8 @@ std::string retention::downtime::service_description() const throw() {
  *
  * @return The start_time.
  */
-time_t retention::downtime::start_time() const throw() {
-  return (_start_time);
+time_t retention::downtime::start_time() const noexcept {
+  return _start_time;
 }
 
 /**
@@ -247,8 +248,8 @@ time_t retention::downtime::start_time() const throw() {
  *
  * @return The triggered_by.
  */
-unsigned long retention::downtime::triggered_by() const throw() {
-  return (_triggered_by);
+unsigned long retention::downtime::triggered_by() const noexcept {
+  return _triggered_by;
 }
 
 /**
@@ -256,9 +257,9 @@ unsigned long retention::downtime::triggered_by() const throw() {
  *
  *  @param[in] value The new author.
  */
-bool retention::downtime::_set_author(std::string const& value) {
+bool retention::downtime::_set_author(const std::string& value) {
   _author = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -266,9 +267,9 @@ bool retention::downtime::_set_author(std::string const& value) {
  *
  *  @param[in] value The new comment_data.
  */
-bool retention::downtime::_set_comment_data(std::string const& value) {
+bool retention::downtime::_set_comment_data(const std::string& value) {
   _comment_data = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -278,7 +279,7 @@ bool retention::downtime::_set_comment_data(std::string const& value) {
  */
 bool retention::downtime::_set_downtime_id(unsigned long value) {
   _downtime_id = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -288,7 +289,7 @@ bool retention::downtime::_set_downtime_id(unsigned long value) {
  */
 bool retention::downtime::_set_duration(unsigned long value) {
   _duration = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -298,7 +299,7 @@ bool retention::downtime::_set_duration(unsigned long value) {
  */
 bool retention::downtime::_set_end_time(time_t value) {
   _end_time = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -308,7 +309,7 @@ bool retention::downtime::_set_end_time(time_t value) {
  */
 bool retention::downtime::_set_entry_time(time_t value) {
   _entry_time = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -318,7 +319,7 @@ bool retention::downtime::_set_entry_time(time_t value) {
  */
 bool retention::downtime::_set_fixed(bool value) {
   _fixed = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -326,9 +327,9 @@ bool retention::downtime::_set_fixed(bool value) {
  *
  *  @param[in] value The new host_name.
  */
-bool retention::downtime::_set_host_name(std::string const& value) {
+bool retention::downtime::_set_host_name(const std::string& value) {
   _host_name = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -336,9 +337,9 @@ bool retention::downtime::_set_host_name(std::string const& value) {
  *
  *  @param[in] value The new service_description.
  */
-bool retention::downtime::_set_service_description(std::string const& value) {
+bool retention::downtime::_set_service_description(const std::string& value) {
   _service_description = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -348,7 +349,7 @@ bool retention::downtime::_set_service_description(std::string const& value) {
  */
 bool retention::downtime::_set_start_time(time_t value) {
   _start_time = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -358,5 +359,5 @@ bool retention::downtime::_set_start_time(time_t value) {
  */
 bool retention::downtime::_set_triggered_by(unsigned long value) {
   _triggered_by = value;
-  return (true);
+  return true;
 }
