@@ -46,11 +46,7 @@ class PbSimpleCommand : public ::testing::Test {
     logger = log_v2::instance().get(log_v2::COMMANDS);
     set_time(-1);
     init_config_state();
-#ifdef LEGACY_CONF
-    config->interval_length(1);
-#else
     pb_config.set_interval_length(1);
-#endif
   }
 
   void TearDown() override { deinit_config_state(); }
@@ -119,10 +115,10 @@ TEST_F(PbSimpleCommand, NewCommandSync) {
 // When async executed
 // Then we have the output in the result class.
 TEST_F(PbSimpleCommand, NewCommandAsync) {
-  std::shared_ptr<my_listener> lstnr = std::make_shared<my_listener>();
+  std::unique_ptr<my_listener> lstnr(new my_listener);
   std::shared_ptr<commands::command> cmd{
       new commands::raw_v2(g_io_context, "test", "/bin/echo bonjour")};
-  cmd->set_listener(lstnr);
+  cmd->set_listener(lstnr.get());
   nagios_macros* mac(get_global_macros());
   std::string cc(cmd->process_cmd(mac));
   ASSERT_EQ(cc, "/bin/echo bonjour");
@@ -138,10 +134,10 @@ TEST_F(PbSimpleCommand, NewCommandAsync) {
 }
 
 TEST_F(PbSimpleCommand, LongCommandAsync) {
-  std::shared_ptr<my_listener> lstnr = std::make_shared<my_listener>();
+  std::unique_ptr<my_listener> lstnr(new my_listener);
   std::shared_ptr<commands::command> cmd{
       new commands::raw_v2(g_io_context, "test", "/bin/sleep 10")};
-  cmd->set_listener(lstnr);
+  cmd->set_listener(lstnr.get());
   nagios_macros* mac(get_global_macros());
   std::string cc(cmd->process_cmd(mac));
   ASSERT_EQ(cc, "/bin/sleep 10");
@@ -167,12 +163,18 @@ TEST_F(PbSimpleCommand, TooRecentDoubleCommand) {
 
   const char* path = "/tmp/TooRecentDoubleCommand";
   ::unlink(path);
-  std::shared_ptr<my_listener> lstnr = std::make_shared<my_listener>();
-  ;
+  std::unique_ptr<my_listener> lstnr(std::make_unique<my_listener>());
   std::shared_ptr<commands::command> cmd{std::make_unique<commands::raw_v2>(
       g_io_context, "test", "/bin/sh /tmp/TooRecentDoubleCommand.sh")};
-  cmd->set_listener(lstnr);
-  const void* caller[] = {nullptr, path};
+  cmd->set_listener(lstnr.get());
+  /**
+   * @brief system that checks that a caller does not execute a command too
+   * frequently needs only void pointers, no needs of real notifier object, so
+   * we use this fake notifier array
+   *
+   */
+  const notifier* caller[] = {reinterpret_cast<const notifier*>(1),
+                              reinterpret_cast<const notifier*>(2)};
   cmd->add_caller_group(caller, caller + 2);
   nagios_macros* mac(get_global_macros());
   std::string cc(cmd->process_cmd(mac));
@@ -210,12 +212,18 @@ TEST_F(PbSimpleCommand, SufficientOldDoubleCommand) {
 
   const char* path = "/tmp/TooRecentDoubleCommand";
   ::unlink(path);
-  std::shared_ptr<my_listener> lstnr = std::make_shared<my_listener>();
-  ;
+  std::unique_ptr<my_listener> lstnr(std::make_unique<my_listener>());
   std::shared_ptr<commands::command> cmd{std::make_unique<commands::raw_v2>(
       g_io_context, "test", "/bin/sh /tmp/TooRecentDoubleCommand.sh")};
-  cmd->set_listener(lstnr);
-  const void* caller[] = {nullptr, path};
+  cmd->set_listener(lstnr.get());
+  /**
+   * @brief system that checks that a caller does not execute a command too
+   * frequently needs only void pointers, no needs of real notifier object, so
+   * we use this fake notifier array
+   *
+   */
+  const notifier* caller[] = {reinterpret_cast<const notifier*>(1),
+                              reinterpret_cast<const notifier*>(2)};
   cmd->add_caller_group(caller, caller + 2);
   nagios_macros* mac(get_global_macros());
   std::string cc(cmd->process_cmd(mac));
@@ -249,10 +257,10 @@ TEST_F(PbSimpleCommand, SufficientOldDoubleCommand) {
 }
 
 TEST_F(PbSimpleCommand, WithOneArgument) {
-  std::shared_ptr<my_listener> lstnr = std::make_shared<my_listener>();
+  auto lstnr = std::make_unique<my_listener>();
   std::shared_ptr<commands::command> cmd{std::make_unique<commands::raw_v2>(
       g_io_context, "test", "/bin/echo $ARG1$")};
-  cmd->set_listener(lstnr);
+  cmd->set_listener(lstnr.get());
   nagios_macros* mac(get_global_macros());
   mac->argv[0] = "Hello";
   mac->argv[1] = "";
