@@ -18,14 +18,15 @@
  */
 
 #include <gtest/gtest.h>
+#include "com/centreon/engine/commands/command.hh"
 #include "com/centreon/engine/configuration/applier/command.hh"
 #include "com/centreon/engine/configuration/applier/connector.hh"
 #include "com/centreon/engine/configuration/applier/contact.hh"
 #include "com/centreon/engine/configuration/applier/contactgroup.hh"
 #include "com/centreon/engine/configuration/applier/timeperiod.hh"
-#include "com/centreon/engine/configuration/contact.hh"
 #include "com/centreon/engine/contact.hh"
 #include "com/centreon/engine/contactgroup.hh"
+#include "common/engine_legacy_conf/contact.hh"
 #include "helper.hh"
 
 using namespace com::centreon;
@@ -33,16 +34,9 @@ using namespace com::centreon::engine;
 using namespace com::centreon::engine::configuration;
 using namespace com::centreon::engine::configuration::applier;
 
-extern int config_errors;
-extern int config_warnings;
-
 class ApplierContact : public ::testing::Test {
  public:
-  void SetUp() override {
-    config_errors = 0;
-    config_warnings = 0;
-    init_config_state();
-  }
+  void SetUp() override { init_config_state(); }
 
   void TearDown() override { deinit_config_state(); }
 
@@ -199,7 +193,8 @@ TEST_F(ApplierContact, ResolveContactFromConfig) {
   aply_grp.add_object(grp);
   aply.add_object(ctct);
   aply.expand_objects(*config);
-  ASSERT_THROW(aply.resolve_object(ctct), std::exception);
+  error_cnt err;
+  ASSERT_THROW(aply.resolve_object(ctct, err), std::exception);
 }
 
 // Given a contact
@@ -216,9 +211,10 @@ TEST_F(ApplierContact, ResolveContactNoNotification) {
   configuration::contact ctct("test");
   aply.add_object(ctct);
   aply.expand_objects(*config);
-  ASSERT_THROW(aply.resolve_object(ctct), std::exception);
-  ASSERT_EQ(config_warnings, 2);
-  ASSERT_EQ(config_errors, 2);
+  error_cnt err;
+  ASSERT_THROW(aply.resolve_object(ctct, err), std::exception);
+  ASSERT_EQ(err.config_warnings, 2);
+  ASSERT_EQ(err.config_errors, 2);
 }
 
 // Given a valid contact
@@ -236,9 +232,10 @@ TEST_F(ApplierContact, ResolveValidContact) {
   configuration::contact ctct(valid_contact_config());
   aply.add_object(ctct);
   aply.expand_objects(*config);
-  ASSERT_NO_THROW(aply.resolve_object(ctct));
-  ASSERT_EQ(config_warnings, 0);
-  ASSERT_EQ(config_errors, 0);
+  error_cnt err;
+  ASSERT_NO_THROW(aply.resolve_object(ctct, err));
+  ASSERT_EQ(err.config_warnings, 0);
+  ASSERT_EQ(err.config_errors, 0);
 }
 
 // Given a valid contact
@@ -252,9 +249,10 @@ TEST_F(ApplierContact, ResolveNonExistingServiceNotificationTimeperiod) {
   ctct.parse("service_notification_period", "non_existing_period");
   aply.add_object(ctct);
   aply.expand_objects(*config);
-  ASSERT_THROW(aply.resolve_object(ctct), std::exception);
-  ASSERT_EQ(config_warnings, 0);
-  ASSERT_EQ(config_errors, 1);
+  error_cnt err;
+  ASSERT_THROW(aply.resolve_object(ctct, err), std::exception);
+  ASSERT_EQ(err.config_warnings, 0);
+  ASSERT_EQ(err.config_errors, 1);
 }
 
 // Given a valid contact
@@ -268,9 +266,10 @@ TEST_F(ApplierContact, ResolveNonExistingHostNotificationTimeperiod) {
   ctct.parse("host_notification_period", "non_existing_period");
   aply.add_object(ctct);
   aply.expand_objects(*config);
-  ASSERT_THROW(aply.resolve_object(ctct), std::exception);
-  ASSERT_EQ(config_warnings, 0);
-  ASSERT_EQ(config_errors, 1);
+  error_cnt err;
+  ASSERT_THROW(aply.resolve_object(ctct, err), std::exception);
+  ASSERT_EQ(err.config_warnings, 0);
+  ASSERT_EQ(err.config_errors, 1);
 }
 
 // Given a valid contact
@@ -284,9 +283,10 @@ TEST_F(ApplierContact, ResolveNonExistingServiceCommand) {
   ctct.parse("service_notification_commands", "non_existing_command");
   aply.add_object(ctct);
   aply.expand_objects(*config);
-  ASSERT_THROW(aply.resolve_object(ctct), std::exception);
-  ASSERT_EQ(config_warnings, 0);
-  ASSERT_EQ(config_errors, 1);
+  error_cnt err;
+  ASSERT_THROW(aply.resolve_object(ctct, err), std::exception);
+  ASSERT_EQ(err.config_warnings, 0);
+  ASSERT_EQ(err.config_errors, 1);
 }
 
 // Given a valid contact
@@ -300,9 +300,10 @@ TEST_F(ApplierContact, ResolveNonExistingHostCommand) {
   ctct.parse("host_notification_commands", "non_existing_command");
   aply.add_object(ctct);
   aply.expand_objects(*config);
-  ASSERT_THROW(aply.resolve_object(ctct), std::exception);
-  ASSERT_EQ(config_warnings, 0);
-  ASSERT_EQ(config_errors, 1);
+  error_cnt err;
+  ASSERT_THROW(aply.resolve_object(ctct, err), std::exception);
+  ASSERT_EQ(err.config_warnings, 0);
+  ASSERT_EQ(err.config_errors, 1);
 }
 
 // Given a valid contact configuration
@@ -365,9 +366,10 @@ TEST_F(ApplierContact, ContactWithOnlyHostRecoveryNotification) {
   ctct.parse("service_notifications_enabled", "1");
   aply.add_object(ctct);
   aply.expand_objects(*config);
-  aply.resolve_object(ctct);
-  ASSERT_EQ(config_warnings, 1);
-  ASSERT_EQ(config_errors, 0);
+  error_cnt err;
+  aply.resolve_object(ctct, err);
+  ASSERT_EQ(err.config_warnings, 1);
+  ASSERT_EQ(err.config_errors, 0);
 }
 
 // Given a valid contact
@@ -384,7 +386,8 @@ TEST_F(ApplierContact, ContactWithOnlyServiceRecoveryNotification) {
   ctct.parse("service_notifications_enabled", "1");
   aply.add_object(ctct);
   aply.expand_objects(*config);
-  aply.resolve_object(ctct);
-  ASSERT_EQ(config_warnings, 1);
-  ASSERT_EQ(config_errors, 0);
+  error_cnt err;
+  aply.resolve_object(ctct, err);
+  ASSERT_EQ(err.config_warnings, 1);
+  ASSERT_EQ(err.config_errors, 0);
 }
