@@ -18,12 +18,13 @@
  */
 
 #include <gtest/gtest.h>
-#include <com/centreon/engine/configuration/applier/host.hh>
-#include <com/centreon/engine/configuration/applier/hostescalation.hh>
-#include <com/centreon/engine/configuration/state.hh>
 #include <com/centreon/engine/host.hh>
 #include <com/centreon/engine/hostescalation.hh>
 #include <helper.hh>
+#include "com/centreon/engine/configuration/applier/host.hh"
+#include "com/centreon/engine/configuration/applier/hostescalation.hh"
+#include "com/centreon/engine/configuration/applier/state.hh"
+#include "common/engine_legacy_conf/state.hh"
 
 using namespace com::centreon;
 using namespace com::centreon::engine;
@@ -55,6 +56,25 @@ TEST_F(ApplierHostEscalation, AddEscalation) {
   ASSERT_EQ(hostescalation::hostescalations.size(), 2u);
 }
 
+TEST_F(ApplierHostEscalation, ResolveObject) {
+  configuration::error_cnt err;
+  configuration::applier::host hst_aply;
+  configuration::host hst;
+  ASSERT_TRUE(hst.parse("host_name", "test_host"));
+  ASSERT_TRUE(hst.parse("address", "127.0.0.1"));
+  ASSERT_TRUE(hst.parse("_HOST_ID", "12"));
+  hst_aply.add_object(hst);
+  ASSERT_EQ(host::hosts.size(), 1u);
+
+  configuration::applier::hostescalation he_apply;
+  configuration::hostescalation he;
+  ASSERT_TRUE(he.parse("host_name", "test_host"));
+  ASSERT_TRUE(he.parse("first_notification", "4"));
+  ASSERT_THROW(he_apply.resolve_object(he, err), std::exception);
+  he_apply.add_object(he);
+  ASSERT_NO_THROW(he_apply.resolve_object(he, err));
+}
+
 TEST_F(ApplierHostEscalation, RemoveEscalation) {
   configuration::applier::host hst_aply;
   configuration::host hst;
