@@ -40,11 +40,6 @@
 #include "com/centreon/engine/serviceescalation.hh"
 #include "com/centreon/engine/timeperiod.hh"
 #include "gtest/gtest.h"
-#ifdef LEGACY_CONF
-#include "common/engine_legacy_conf/host.hh"
-#include "common/engine_legacy_conf/service.hh"
-#include "common/engine_legacy_conf/state.hh"
-#endif
 #include "helper.hh"
 
 using namespace com::centreon;
@@ -59,43 +54,21 @@ class ServiceTimePeriodNotification : public TestEngine {
     init_config_state();
 
     configuration::applier::contact ct_aply;
-#ifdef LEGACY_CONF
-    configuration::contact ctct{new_configuration_contact("admin", true)};
-#else
     configuration::Contact ctct{new_pb_configuration_contact("admin", true)};
-#endif
     ct_aply.add_object(ctct);
-#ifdef LEGACY_CONF
-    configuration::contact ctct1{
-        new_configuration_contact("admin1", false, "c,r")};
-#else
     configuration::Contact ctct1{
         new_pb_configuration_contact("admin1", false, "c,r")};
-#endif
     ct_aply.add_object(ctct1);
-#ifdef LEGACY_CONF
-    ct_aply.expand_objects(*config);
-#else
     ct_aply.expand_objects(pb_config);
-#endif
     ct_aply.resolve_object(ctct, err);
     ct_aply.resolve_object(ctct1, err);
 
-#ifdef LEGACY_CONF
-    configuration::host hst{new_configuration_host("test_host", "admin")};
-#else
     configuration::Host hst{new_pb_configuration_host("test_host", "admin")};
-#endif
     configuration::applier::host hst_aply;
     hst_aply.add_object(hst);
 
-#ifdef LEGACY_CONF
-    configuration::service svc{
-        new_configuration_service("test_host", "test_svc", "admin,admin1")};
-#else
     configuration::Service svc{
         new_pb_configuration_service("test_host", "test_svc", "admin,admin1")};
-#endif
     configuration::applier::service svc_aply;
     svc_aply.add_object(svc);
 
@@ -152,50 +125,24 @@ TEST_F(ServiceTimePeriodNotification, NoTimePeriodOk) {
   set_time(now);
 
   configuration::applier::contact ct_aply;
-#ifdef LEGACY_CONF
-  configuration::contact ctct{new_configuration_contact("test_contact", false)};
-#else
   configuration::Contact ctct{
       new_pb_configuration_contact("test_contact", false)};
-#endif
   ct_aply.add_object(ctct);
-#ifdef LEGACY_CONF
-  ct_aply.expand_objects(*config);
-#else
   ct_aply.expand_objects(pb_config);
-#endif
   ct_aply.resolve_object(ctct, err);
 
   configuration::applier::contactgroup cg_aply;
-#ifdef LEGACY_CONF
-  configuration::contactgroup cg{
-      new_configuration_contactgroup("test_cg", "test_contact")};
-#else
   configuration::Contactgroup cg{
       new_pb_configuration_contactgroup("test_cg", "test_contact")};
-#endif
   cg_aply.add_object(cg);
-#ifdef LEGACY_CONF
-  cg_aply.expand_objects(*config);
-#else
   cg_aply.expand_objects(pb_config);
-#endif
   cg_aply.resolve_object(cg, err);
 
   configuration::applier::serviceescalation se_aply;
-#ifdef LEGACY_CONF
-  configuration::serviceescalation se{
-      new_configuration_serviceescalation("test_host", "test_svc", "test_cg")};
-#else
   configuration::Serviceescalation se{new_pb_configuration_serviceescalation(
       "test_host", "test_svc", "test_cg")};
-#endif
   se_aply.add_object(se);
-#ifdef LEGACY_CONF
-  se_aply.expand_objects(*config);
-#else
   se_aply.expand_objects(pb_config);
-#endif
   se_aply.resolve_object(se, err);
 
   // uint64_t id{_svc->get_next_notification_id()};
@@ -284,47 +231,20 @@ TEST_F(ServiceTimePeriodNotification, NoTimePeriodKo) {
   set_time(now);
 
   configuration::applier::contact ct_aply;
-#ifdef LEGACY_CONF
-  configuration::contact ctct{new_configuration_contact("test_contact", false)};
-#else
   configuration::Contact ctct{
       new_pb_configuration_contact("test_contact", false)};
-#endif
   ct_aply.add_object(ctct);
-#ifdef LEGACY_CONF
-  ct_aply.expand_objects(*config);
-#else
   ct_aply.expand_objects(pb_config);
-#endif
   ct_aply.resolve_object(ctct, err);
 
   configuration::applier::contactgroup cg_aply;
-#ifdef LEGACY_CONF
-  configuration::contactgroup cg{
-      new_configuration_contactgroup("test_cg", "test_contact")};
-#else
   configuration::Contactgroup cg{
       new_pb_configuration_contactgroup("test_cg", "test_contact")};
-#endif
   cg_aply.add_object(cg);
-#ifdef LEGACY_CONF
-  cg_aply.expand_objects(*config);
-#else
   cg_aply.expand_objects(pb_config);
-#endif
   cg_aply.resolve_object(cg, err);
 
   configuration::applier::serviceescalation se_aply;
-#ifdef LEGACY_CONF
-  configuration::serviceescalation se;
-  se.parse("first_notification", "1");
-  se.parse("last_notification", "1");
-  se.parse("notification_interval", "0");
-  se.parse("escalation_options", "w,u,c,r");
-  se.parse("host_name", "test_host");
-  se.parse("service_description", "test_svc");
-  se.parse("contact_groups", "test_cg");
-#else
   configuration::Serviceescalation se;
   configuration::serviceescalation_helper se_hlp(&se);
   se.set_first_notification(1);
@@ -334,13 +254,8 @@ TEST_F(ServiceTimePeriodNotification, NoTimePeriodKo) {
   se_hlp.hook("host_name", "test_host");
   se_hlp.hook("service_description", "test_svc");
   se_hlp.hook("contact_groups", "test_cg");
-#endif
   se_aply.add_object(se);
-#ifdef LEGACY_CONF
-  se_aply.expand_objects(*config);
-#else
   se_aply.expand_objects(pb_config);
-#endif
   se_aply.resolve_object(se, err);
   for (int i = 0; i < 7; ++i) {
     timerange_list list_time;
@@ -434,50 +349,24 @@ TEST_F(ServiceTimePeriodNotification, TimePeriodOut) {
   set_time(now);
 
   configuration::applier::contact ct_aply;
-#ifdef LEGACY_CONF
-  configuration::contact ctct{new_configuration_contact("test_contact", false)};
-#else
   configuration::Contact ctct{
       new_pb_configuration_contact("test_contact", false)};
-#endif
   ct_aply.add_object(ctct);
-#ifdef LEGACY_CONF
-  ct_aply.expand_objects(*config);
-#else
   ct_aply.expand_objects(pb_config);
-#endif
   ct_aply.resolve_object(ctct, err);
 
   configuration::applier::contactgroup cg_aply;
-#ifdef LEGACY_CONF
-  configuration::contactgroup cg{
-      new_configuration_contactgroup("test_cg", "test_contact")};
-#else
   configuration::Contactgroup cg{
       new_pb_configuration_contactgroup("test_cg", "test_contact")};
-#endif
   cg_aply.add_object(cg);
-#ifdef LEGACY_CONF
-  cg_aply.expand_objects(*config);
-#else
   cg_aply.expand_objects(pb_config);
-#endif
   cg_aply.resolve_object(cg, err);
 
   configuration::applier::serviceescalation se_aply;
-#ifdef LEGACY_CONF
-  configuration::serviceescalation se{
-      new_configuration_serviceescalation("test_host", "test_svc", "test_cg")};
-#else
   configuration::Serviceescalation se{new_pb_configuration_serviceescalation(
       "test_host", "test_svc", "test_cg")};
-#endif
   se_aply.add_object(se);
-#ifdef LEGACY_CONF
-  se_aply.expand_objects(*config);
-#else
   se_aply.expand_objects(pb_config);
-#endif
   se_aply.resolve_object(se, err);
 
   // uint64_t id{_svc->get_next_notification_id()};
@@ -564,18 +453,6 @@ TEST_F(ServiceTimePeriodNotification, TimePeriodUserOut) {
       new_timeperiod_with_timeranges("tperiod", "alias")};
   int now{20000};
   set_time(now);
-#ifdef LEGACY_CONF
-  configuration::timeperiod tperiod;
-  tperiod.parse("timeperiod_name", "24x9");
-  tperiod.parse("alias", "24x9");
-  tperiod.parse("monday", "00:00-09:00");
-  tperiod.parse("tuesday", "00:00-09:00");
-  tperiod.parse("wednesday", "00:00-09:00");
-  tperiod.parse("thursday", "00:00-09:00");
-  tperiod.parse("friday", "00:00-09:00");
-  tperiod.parse("saterday", "00:00-09:00");
-  tperiod.parse("sunday", "00:00-09:00");
-#else
   configuration::Timeperiod tperiod;
   configuration::timeperiod_helper tperiod_hlp(&tperiod);
   tperiod.set_timeperiod_name("24x9");
@@ -587,22 +464,10 @@ TEST_F(ServiceTimePeriodNotification, TimePeriodUserOut) {
   tperiod_hlp.hook("friday", "00:00-09:00");
   tperiod_hlp.hook("saterday", "00:00-09:00");
   tperiod_hlp.hook("sunday", "00:00-09:00");
-#endif
   configuration::applier::timeperiod aplyr;
   aplyr.add_object(tperiod);
 
   configuration::applier::contact ct_aply;
-#ifdef LEGACY_CONF
-  configuration::contact ctct;
-  ctct.parse("contact_name", "test_contact");
-  ctct.parse("service_notification_period", "24x9");
-  ctct.parse("host_notification_commands", "cmd");
-  ctct.parse("service_notification_commands", "cmd");
-  ctct.parse("host_notification_options", "d,r,f,s");
-  ctct.parse("service_notification_options", "a");
-  ctct.parse("host_notifications_enabled", "1");
-  ctct.parse("service_notifications_enabled", "1");
-#else
   configuration::Contact ctct;
   configuration::contact_helper ctct_hlp(&ctct);
   ctct.set_contact_name("test_contact");
@@ -613,46 +478,23 @@ TEST_F(ServiceTimePeriodNotification, TimePeriodUserOut) {
   ctct_hlp.hook("service_notification_options", "a");
   ctct.set_host_notifications_enabled(true);
   ctct.set_service_notifications_enabled(true);
-#endif
 
   ct_aply.add_object(ctct);
-#ifdef LEGACY_CONF
-  ct_aply.expand_objects(*config);
-#else
   ct_aply.expand_objects(pb_config);
-#endif
   ct_aply.resolve_object(ctct, err);
 
   configuration::applier::contactgroup cg_aply;
-#ifdef LEGACY_CONF
-  configuration::contactgroup cg{
-      new_configuration_contactgroup("test_cg", "test_contact")};
-#else
   configuration::Contactgroup cg{
       new_pb_configuration_contactgroup("test_cg", "test_contact")};
-#endif
   cg_aply.add_object(cg);
-#ifdef LEGACY_CONF
-  cg_aply.expand_objects(*config);
-#else
   cg_aply.expand_objects(pb_config);
-#endif
   cg_aply.resolve_object(cg, err);
 
   configuration::applier::serviceescalation se_aply;
-#ifdef LEGACY_CONF
-  configuration::serviceescalation se{
-      new_configuration_serviceescalation("test_host", "test_svc", "test_cg")};
-#else
   configuration::Serviceescalation se{new_pb_configuration_serviceescalation(
       "test_host", "test_svc", "test_cg")};
-#endif
   se_aply.add_object(se);
-#ifdef LEGACY_CONF
-  se_aply.expand_objects(*config);
-#else
   se_aply.expand_objects(pb_config);
-#endif
   se_aply.resolve_object(se, err);
 
   // uint64_t id{_svc->get_next_notification_id()};
@@ -738,18 +580,6 @@ TEST_F(ServiceTimePeriodNotification, TimePeriodUserIn) {
       new_timeperiod_with_timeranges("tperiod", "alias")};
   int now{20000};
   set_time(now);
-#ifdef LEGACY_CONF
-  configuration::timeperiod tperiod;
-  tperiod.parse("timeperiod_name", "24x9");
-  tperiod.parse("alias", "24x9");
-  tperiod.parse("monday", "09:00-20:00");
-  tperiod.parse("tuesday", "09:00-20:00");
-  tperiod.parse("wednesday", "09:00-20:00");
-  tperiod.parse("thursday", "09:00-20:00");
-  tperiod.parse("friday", "09:00-20:00");
-  tperiod.parse("saterday", "09:00-20:00");
-  tperiod.parse("sunday", "09:00-20:00");
-#else
   configuration::Timeperiod tperiod;
   configuration::timeperiod_helper tperiod_hlp(&tperiod);
   tperiod.set_timeperiod_name("24x9");
@@ -761,22 +591,10 @@ TEST_F(ServiceTimePeriodNotification, TimePeriodUserIn) {
   tperiod_hlp.hook("friday", "09:00-20:00");
   tperiod_hlp.hook("saterday", "09:00-20:00");
   tperiod_hlp.hook("sunday", "09:00-20:00");
-#endif
   configuration::applier::timeperiod aplyr;
   aplyr.add_object(tperiod);
 
   configuration::applier::contact ct_aply;
-#ifdef LEGACY_CONF
-  configuration::contact ctct;
-  ctct.parse("contact_name", "test_contact");
-  ctct.parse("service_notification_period", "24x9");
-  ctct.parse("host_notification_commands", "cmd");
-  ctct.parse("service_notification_commands", "cmd");
-  ctct.parse("host_notification_options", "d,r,f,s");
-  ctct.parse("service_notification_options", "a");
-  ctct.parse("host_notifications_enabled", "1");
-  ctct.parse("service_notifications_enabled", "1");
-#else
   configuration::Contact ctct;
   configuration::contact_helper ctct_hlp(&ctct);
   ctct.set_contact_name("test_contact");
@@ -787,46 +605,23 @@ TEST_F(ServiceTimePeriodNotification, TimePeriodUserIn) {
   ctct_hlp.hook("service_notification_options", "a");
   ctct.set_host_notifications_enabled(true);
   ctct.set_service_notifications_enabled(true);
-#endif
 
   ct_aply.add_object(ctct);
-#ifdef LEGACY_CONF
-  ct_aply.expand_objects(*config);
-#else
   ct_aply.expand_objects(pb_config);
-#endif
   ct_aply.resolve_object(ctct, err);
 
   configuration::applier::contactgroup cg_aply;
-#ifdef LEGACY_CONF
-  configuration::contactgroup cg{
-      new_configuration_contactgroup("test_cg", "test_contact")};
-#else
   configuration::Contactgroup cg{
       new_pb_configuration_contactgroup("test_cg", "test_contact")};
-#endif
   cg_aply.add_object(cg);
-#ifdef LEGACY_CONF
-  cg_aply.expand_objects(*config);
-#else
   cg_aply.expand_objects(pb_config);
-#endif
   cg_aply.resolve_object(cg, err);
 
   configuration::applier::serviceescalation se_aply;
-#ifdef LEGACY_CONF
-  configuration::serviceescalation se{
-      new_configuration_serviceescalation("test_host", "test_svc", "test_cg")};
-#else
   configuration::Serviceescalation se{new_pb_configuration_serviceescalation(
       "test_host", "test_svc", "test_cg")};
-#endif
   se_aply.add_object(se);
-#ifdef LEGACY_CONF
-  se_aply.expand_objects(*config);
-#else
   se_aply.expand_objects(pb_config);
-#endif
   se_aply.resolve_object(se, err);
 
   // uint64_t id{_svc->get_next_notification_id()};
@@ -911,18 +706,6 @@ TEST_F(ServiceTimePeriodNotification, TimePeriodUserAll) {
       new_timeperiod_with_timeranges("tperiod", "alias")};
   int now{20000};
   set_time(now);
-#ifdef LEGACY_CONF
-  configuration::timeperiod tperiod;
-  tperiod.parse("timeperiod_name", "24x9");
-  tperiod.parse("alias", "24x9");
-  tperiod.parse("monday", "00:00-24:00");
-  tperiod.parse("tuesday", "00:00-24:00");
-  tperiod.parse("wednesday", "00:00-24:00");
-  tperiod.parse("thursday", "00:00-24:00");
-  tperiod.parse("friday", "00:00-24:00");
-  tperiod.parse("saterday", "00:00-24:00");
-  tperiod.parse("sunday", "00:00-24:00");
-#else
   configuration::Timeperiod tperiod;
   configuration::timeperiod_helper tperiod_hlp(&tperiod);
   tperiod.set_timeperiod_name("24x9");
@@ -934,22 +717,10 @@ TEST_F(ServiceTimePeriodNotification, TimePeriodUserAll) {
   tperiod_hlp.hook("friday", "00:00-24:00");
   tperiod_hlp.hook("saterday", "00:00-24:00");
   tperiod_hlp.hook("sunday", "00:00-24:00");
-#endif
   configuration::applier::timeperiod aplyr;
   aplyr.add_object(tperiod);
 
   configuration::applier::contact ct_aply;
-#ifdef LEGACY_CONF
-  configuration::contact ctct;
-  ctct.parse("contact_name", "test_contact");
-  ctct.parse("service_notification_period", "24x9");
-  ctct.parse("host_notification_commands", "cmd");
-  ctct.parse("service_notification_commands", "cmd");
-  ctct.parse("host_notification_options", "d,r,f,s");
-  ctct.parse("service_notification_options", "a");
-  ctct.parse("host_notifications_enabled", "1");
-  ctct.parse("service_notifications_enabled", "1");
-#else
   configuration::Contact ctct;
   configuration::contact_helper ctct_hlp(&ctct);
   ctct.set_contact_name("test_contact");
@@ -960,47 +731,24 @@ TEST_F(ServiceTimePeriodNotification, TimePeriodUserAll) {
   ctct_hlp.hook("service_notification_options", "a");
   ctct.set_host_notifications_enabled(true);
   ctct.set_service_notifications_enabled(true);
-#endif
 
   error_cnt err;
   ct_aply.add_object(ctct);
-#ifdef LEGACY_CONF
-  ct_aply.expand_objects(*config);
-#else
   ct_aply.expand_objects(pb_config);
-#endif
   ct_aply.resolve_object(ctct, err);
 
   configuration::applier::contactgroup cg_aply;
-#ifdef LEGACY_CONF
-  configuration::contactgroup cg{
-      new_configuration_contactgroup("test_cg", "test_contact")};
-#else
   configuration::Contactgroup cg{
       new_pb_configuration_contactgroup("test_cg", "test_contact")};
-#endif
   cg_aply.add_object(cg);
-#ifdef LEGACY_CONF
-  cg_aply.expand_objects(*config);
-#else
   cg_aply.expand_objects(pb_config);
-#endif
   cg_aply.resolve_object(cg, err);
 
   configuration::applier::serviceescalation se_aply;
-#ifdef LEGACY_CONF
-  configuration::serviceescalation se{
-      new_configuration_serviceescalation("test_host", "test_svc", "test_cg")};
-#else
   configuration::Serviceescalation se{new_pb_configuration_serviceescalation(
       "test_host", "test_svc", "test_cg")};
-#endif
   se_aply.add_object(se);
-#ifdef LEGACY_CONF
-  se_aply.expand_objects(*config);
-#else
   se_aply.expand_objects(pb_config);
-#endif
   se_aply.resolve_object(se, err);
 
   // uint64_t id{_svc->get_next_notification_id()};
@@ -1085,31 +833,14 @@ TEST_F(ServiceTimePeriodNotification, TimePeriodUserNone) {
       new_timeperiod_with_timeranges("tperiod", "alias")};
   int now{20000};
   set_time(now);
-#ifdef LEGACY_CONF
-  configuration::timeperiod tperiod;
-  tperiod.parse("timeperiod_name", "24x9");
-  tperiod.parse("alias", "24x9");
-#else
   configuration::Timeperiod tperiod;
   configuration::timeperiod_helper tperiod_hlp(&tperiod);
   tperiod.set_timeperiod_name("24x9");
   tperiod.set_alias("24x9");
-#endif
   configuration::applier::timeperiod aplyr;
   aplyr.add_object(tperiod);
 
   configuration::applier::contact ct_aply;
-#ifdef LEGACY_CONF
-  configuration::contact ctct;
-  ctct.parse("contact_name", "test_contact");
-  ctct.parse("service_notification_period", "24x9");
-  ctct.parse("host_notification_commands", "cmd");
-  ctct.parse("service_notification_commands", "cmd");
-  ctct.parse("host_notification_options", "d,r,f,s");
-  ctct.parse("service_notification_options", "a");
-  ctct.parse("host_notifications_enabled", "1");
-  ctct.parse("service_notifications_enabled", "1");
-#else
   configuration::Contact ctct;
   configuration::contact_helper ctct_hlp(&ctct);
   ctct.set_contact_name("test_contact");
@@ -1120,47 +851,24 @@ TEST_F(ServiceTimePeriodNotification, TimePeriodUserNone) {
   ctct_hlp.hook("service_notification_options", "a");
   ctct.set_host_notifications_enabled(true);
   ctct.set_service_notifications_enabled(true);
-#endif
 
   error_cnt err;
   ct_aply.add_object(ctct);
-#ifdef LEGACY_CONF
-  ct_aply.expand_objects(*config);
-#else
   ct_aply.expand_objects(pb_config);
-#endif
   ct_aply.resolve_object(ctct, err);
 
   configuration::applier::contactgroup cg_aply;
-#ifdef LEGACY_CONF
-  configuration::contactgroup cg{
-      new_configuration_contactgroup("test_cg", "test_contact")};
-#else
   configuration::Contactgroup cg{
       new_pb_configuration_contactgroup("test_cg", "test_contact")};
-#endif
   cg_aply.add_object(cg);
-#ifdef LEGACY_CONF
-  cg_aply.expand_objects(*config);
-#else
   cg_aply.expand_objects(pb_config);
-#endif
   cg_aply.resolve_object(cg, err);
 
   configuration::applier::serviceescalation se_aply;
-#ifdef LEGACY_CONF
-  configuration::serviceescalation se{
-      new_configuration_serviceescalation("test_host", "test_svc", "test_cg")};
-#else
   configuration::Serviceescalation se{new_pb_configuration_serviceescalation(
       "test_host", "test_svc", "test_cg")};
-#endif
   se_aply.add_object(se);
-#ifdef LEGACY_CONF
-  se_aply.expand_objects(*config);
-#else
   se_aply.expand_objects(pb_config);
-#endif
   se_aply.resolve_object(se, err);
 
   // uint64_t id{_svc->get_next_notification_id()};
@@ -1245,30 +953,14 @@ TEST_F(ServiceTimePeriodNotification, NoTimePeriodUser) {
       new_timeperiod_with_timeranges("tperiod", "alias")};
   int now{20000};
   set_time(now);
-#ifdef LEGACY_CONF
-  configuration::timeperiod tperiod;
-  tperiod.parse("timeperiod_name", "24x9");
-  tperiod.parse("alias", "24x9");
-#else
   configuration::Timeperiod tperiod;
   configuration::timeperiod_helper tperiod_hlp(&tperiod);
   tperiod.set_timeperiod_name("24x9");
   tperiod.set_alias("24x9");
-#endif
   configuration::applier::timeperiod aplyr;
   aplyr.add_object(tperiod);
 
   configuration::applier::contact ct_aply;
-#ifdef LEGACY_CONF
-  configuration::contact ctct;
-  ctct.parse("contact_name", "test_contact");
-  ctct.parse("host_notification_commands", "cmd");
-  ctct.parse("service_notification_commands", "cmd");
-  ctct.parse("host_notification_options", "d,r,f,s");
-  ctct.parse("service_notification_options", "a");
-  ctct.parse("host_notifications_enabled", "1");
-  ctct.parse("service_notifications_enabled", "1");
-#else
   configuration::Contact ctct;
   configuration::contact_helper ctct_hlp(&ctct);
   ctct.set_contact_name("test_contact");
@@ -1278,47 +970,24 @@ TEST_F(ServiceTimePeriodNotification, NoTimePeriodUser) {
   ctct_hlp.hook("service_notification_options", "a");
   ctct.set_host_notifications_enabled(true);
   ctct.set_service_notifications_enabled(true);
-#endif
 
   error_cnt err;
   ct_aply.add_object(ctct);
-#ifdef LEGACY_CONF
-  ct_aply.expand_objects(*config);
-#else
   ct_aply.expand_objects(pb_config);
-#endif
   ct_aply.resolve_object(ctct, err);
 
   configuration::applier::contactgroup cg_aply;
-#ifdef LEGACY_CONF
-  configuration::contactgroup cg{
-      new_configuration_contactgroup("test_cg", "test_contact")};
-#else
   configuration::Contactgroup cg{
       new_pb_configuration_contactgroup("test_cg", "test_contact")};
-#endif
   cg_aply.add_object(cg);
-#ifdef LEGACY_CONF
-  cg_aply.expand_objects(*config);
-#else
   cg_aply.expand_objects(pb_config);
-#endif
   cg_aply.resolve_object(cg, err);
 
   configuration::applier::serviceescalation se_aply;
-#ifdef LEGACY_CONF
-  configuration::serviceescalation se{
-      new_configuration_serviceescalation("test_host", "test_svc", "test_cg")};
-#else
   configuration::Serviceescalation se{new_pb_configuration_serviceescalation(
       "test_host", "test_svc", "test_cg")};
-#endif
   se_aply.add_object(se);
-#ifdef LEGACY_CONF
-  se_aply.expand_objects(*config);
-#else
   se_aply.expand_objects(pb_config);
-#endif
   se_aply.resolve_object(se, err);
 
   // uint64_t id{_svc->get_next_notification_id()};
