@@ -17,11 +17,7 @@
  */
 
 #include <gtest/gtest.h>
-#include <boost/multi_index/hashed_index.hpp>
-#include <boost/multi_index/ordered_index.hpp>
-#include <boost/multi_index_container.hpp>
 
-#include "com/centreon/engine/modules/opentelemetry/centreon_agent/agent_stat.hh"
 #include "opentelemetry/proto/collector/metrics/v1/metrics_service.pb.h"
 #include "opentelemetry/proto/common/v1/common.pb.h"
 #include "opentelemetry/proto/metrics/v1/metrics.pb.h"
@@ -80,6 +76,8 @@ struct fake_connector : public to_agent_connector {
 fake_connector::config_to_fake fake_connector::all_fake;
 
 class my_agent_reverse_client : public agent_reverse_client {
+  agent_stat::pointer _stats = std::make_shared<agent_stat>(g_io_context);
+
  public:
   my_agent_reverse_client(
       const std::shared_ptr<boost::asio::io_context>& io_context,
@@ -96,7 +94,7 @@ class my_agent_reverse_client : public agent_reverse_client {
         .try_emplace(
             agent_endpoint,
             fake_connector::load(agent_endpoint, _io_context, agent_conf,
-                                 _metric_handler, _logger, _agent_stats))
+                                 _metric_handler, _logger, _stats))
         .first;
   }
 
@@ -106,26 +104,27 @@ class my_agent_reverse_client : public agent_reverse_client {
 };
 
 TEST(agent_reverse_client, update_config) {
+  agent_stat::pointer stats = std::make_shared<agent_stat>(g_io_context);
   my_agent_reverse_client to_test(
       g_io_context, [](const metric_request_ptr&) {}, spdlog::default_logger(),
-      std::make_shared<agent_stat>(g_io_context));
+      stats);
 
   ASSERT_TRUE(fake_connector::all_fake.empty());
 
   auto agent_conf = std::shared_ptr<centreon_agent::agent_config>(
       new centreon_agent::agent_config(
-          100, 60, 10, {std::make_shared<grpc_config>("host1:port1", false)}));
+          60, 100, 10, {std::make_shared<grpc_config>("host1:port1", false)}));
   to_test.update(agent_conf);
   ASSERT_EQ(fake_connector::all_fake.size(), 1);
   ASSERT_EQ(fake_connector::all_fake.begin()->first,
             *agent_conf->get_agent_grpc_reverse_conf().begin());
-  agent_conf = std::make_shared<centreon_agent::agent_config>(100, 1, 10);
+  agent_conf = std::make_shared<centreon_agent::agent_config>(1, 100, 10);
   to_test.update(agent_conf);
   ASSERT_EQ(fake_connector::all_fake.size(), 0);
 
   agent_conf = std::shared_ptr<centreon_agent::agent_config>(
       new centreon_agent::agent_config(
-          100, 60, 10,
+          60, 100, 10,
           {std::make_shared<grpc_config>("host1:port1", false),
            std::make_shared<grpc_config>("host1:port3", false)}));
   to_test.update(agent_conf);
@@ -134,7 +133,7 @@ TEST(agent_reverse_client, update_config) {
   auto second_conn = (++fake_connector::all_fake.begin())->second;
   agent_conf = std::shared_ptr<centreon_agent::agent_config>(
       new centreon_agent::agent_config(
-          100, 60, 10,
+          60, 100, 10,
           {std::make_shared<grpc_config>("host1:port1", false),
            std::make_shared<grpc_config>("host1:port2", false),
            std::make_shared<grpc_config>("host1:port3", false)}));
@@ -148,7 +147,7 @@ TEST(agent_reverse_client, update_config) {
 
   agent_conf = std::shared_ptr<centreon_agent::agent_config>(
       new centreon_agent::agent_config(
-          100, 60, 10,
+          60, 100, 10,
           {std::make_shared<grpc_config>("host1:port1", false),
            std::make_shared<grpc_config>("host1:port3", false)}));
   to_test.update(agent_conf);
@@ -158,7 +157,7 @@ TEST(agent_reverse_client, update_config) {
 
   agent_conf = std::shared_ptr<centreon_agent::agent_config>(
       new centreon_agent::agent_config(
-          100, 60, 10, {std::make_shared<grpc_config>("host1:port3", false)}));
+          60, 100, 10, {std::make_shared<grpc_config>("host1:port3", false)}));
   to_test.update(agent_conf);
   ASSERT_EQ(fake_connector::all_fake.size(), 1);
   ASSERT_EQ(fake_connector::all_fake.begin()->second, third_conn);
