@@ -49,7 +49,7 @@ TEST(otl_grpc_config, no_host_json) {
 
 TEST(otl_grpc_config, bad_port_json) {
   ASSERT_THROW(grpc_config t(R"(
-{
+{   
     "host":"127.0.0.1",
     "port":1000
 })"_json),
@@ -58,7 +58,7 @@ TEST(otl_grpc_config, bad_port_json) {
 
 TEST(otl_grpc_config, bad_port_json2) {
   ASSERT_THROW(grpc_config t(R"(
-{
+{   
     "host":"127.0.0.1",
     "port":"2500"
 })"_json),
@@ -67,7 +67,7 @@ TEST(otl_grpc_config, bad_port_json2) {
 
 TEST(otl_grpc_config, bad_port_json3) {
   ASSERT_THROW(grpc_config t(R"(
-{
+{   
     "host":"127.0.0.1",
     "port":250000
 })"_json),
@@ -76,7 +76,7 @@ TEST(otl_grpc_config, bad_port_json3) {
 
 TEST(otl_grpc_config, good_host_port) {
   grpc_config c(R"(
-{
+{   
     "host":"127.0.0.1",
     "port":2500
 })"_json);
@@ -92,10 +92,10 @@ TEST(otl_grpc_config, good_host_port) {
 
 TEST(otl_grpc_config, good_host_port2) {
   grpc_config c(R"(
-{
+{   
     "host":"127.0.0.1",
     "port":2500,
-    "encryption":true,
+    "encryption":"full",
     "compression": true,
     "ca_name":"toto"
 })"_json);
@@ -112,10 +112,10 @@ TEST(otl_grpc_config, good_host_port2) {
 // test if we can set trusted tokens
 TEST(otl_grpc_config, tokens) {
   grpc_config c(R"(
-{
+{   
     "host":"127.0.0.1",
     "port":2500,
-    "encryption":true,
+    "encryption":"full",
     "compression": true,
     "ca_name":"toto",
     "token":"token1",
@@ -138,53 +138,53 @@ TEST(otl_grpc_config, tokens) {
 //  test if we can compare trusted tokens
 TEST(otl_grpc_config, tokencompare) {
   grpc_config c(R"(
-{
+{   
     "host":"127.0.0.1",
     "port":2500,
-    "encryption":true,
+    "encryption":"full",
     "compression": true,
     "ca_name":"toto"
 })"_json);
   grpc_config c_same(R"(
-  {
+  {   
       "host":"127.0.0.1",
       "port":2500,
-      "encryption":true,
+      "encryption":"full",
       "compression": true,
       "ca_name":"toto"
   })"_json);
   grpc_config c2(R"(
-  {
+  {   
       "host":"127.0.0.1",
       "port":2500,
-      "encryption":true,
+      "encryption":"full",
       "compression": true,
       "ca_name":"toto",
       "trusted_tokens":["toto","titi"]
   })"_json);
   grpc_config c2_same(R"(
-  {
+  {   
       "host":"127.0.0.1",
       "port":2500,
-      "encryption":true,
+      "encryption":"full",
       "compression": true,
       "ca_name":"toto",
       "trusted_tokens":["toto","titi"]
   })"_json);
   grpc_config c2_minos(R"(
-    {
+    {   
         "host":"127.0.0.1",
         "port":2500,
-        "encryption":true,
+        "encryption":"full",
         "compression": true,
         "ca_name":"toto",
         "trusted_tokens":["toto"]
     })"_json);
   grpc_config c2_plus(R"(
-      {
+      {   
           "host":"127.0.0.1",
           "port":2500,
-          "encryption":true,
+          "encryption":"full",
           "compression": true,
           "ca_name":"toto",
           "trusted_tokens":["toto","titi","tata"]
@@ -258,4 +258,4 @@ TEST(otl_grpc_config, encryption_value) {
   ASSERT_TRUE(conf_true.is_crypted());
   ASSERT_EQ(conf_false.get_security_mode(), grpc_config::NONE);
   ASSERT_FALSE(conf_false.is_crypted());
-}
+}
\ No newline at end of file
